[education/labplot] /: labplot2 rename

Stefan Gerlach <[email protected]>
Newsgroups gmane.comp.kde.cvs,gmane.comp.kde.doc
Message-ID <[email protected]>
Git commit 1768563764ff88e7193d9d4100bb7d5e502e029a by Stefan Gerlach.
Committed on 02/08/2024 at 23:45.
Pushed by sgerlach into branch 'master'.

labplot2 rename

Description
===========
Rename LabPlot2 to LabPlot. LabPlot1 never existed and the version number was always 2.x. When we switch to version 3.x we should leave the "2" behind.

TODO: 
- .knsrc must be sysadmin reviewed
- https://cdn.kde.org/screenshots/labplot2
- .po translations
- flatpak: https://invent.kde.org/sysadmin/ci-utilities/-/blob/master/signing/flatpaksigner-projects.yaml
- snap?

Conformity
==========

- [X] [Changelog entry](https://invent.kde.org/education/labplot/-/blob/master/ChangeLog)

When external dependencies are removed
======================================
- [ ] Reporting to ...

M  +2    -2    .flatpak-manifest.json
M  +0    -3    .gitlab-ci.yml
M  +3    -3    CMakeLists.txt
M  +4    -0    ChangeLog
M  +4    -4    admin/README.release
M  +1    -1    doc/CMakeLists.txt
R  +8    -8    doc/man-labplot.1.docbook [from: doc/man-labplot2.1.docbook - 090% similarity]
R  +-    --    icons/128-application-x-labplot.png [from: icons/128-application-x-labplot2.png - 100% similarity]
R  +-    --    icons/128-apps-labplot.png [from: icons/128-apps-labplot2.png - 100% similarity]
R  +-    --    icons/150-apps-labplot.png [from: icons/150-apps-labplot2.png - 100% similarity]
R  +-    --    icons/16-application-x-labplot.png [from: icons/16-application-x-labplot2.png - 100% similarity]
R  +-    --    icons/16-apps-labplot.png [from: icons/16-apps-labplot2.png - 100% similarity]
R  +-    --    icons/22-application-x-labplot.png [from: icons/22-application-x-labplot2.png - 100% similarity]
R  +-    --    icons/22-apps-labplot.png [from: icons/22-apps-labplot2.png - 100% similarity]
R  +-    --    icons/256-application-x-labplot.png [from: icons/256-application-x-labplot2.png - 100% similarity]
R  +-    --    icons/256-apps-labplot.png [from: icons/256-apps-labplot2.png - 100% similarity]
R  +-    --    icons/310-apps-labplot.png [from: icons/310-apps-labplot2.png - 100% similarity]
R  +-    --    icons/32-application-x-labplot.png [from: icons/32-application-x-labplot2.png - 100% similarity]
R  +-    --    icons/32-apps-labplot.png [from: icons/32-apps-labplot2.png - 100% similarity]
R  +-    --    icons/44-apps-labplot.png [from: icons/44-apps-labplot2.png - 100% similarity]
R  +-    --    icons/48-application-x-labplot.png [from: icons/48-application-x-labplot2.png - 100% similarity]
R  +-    --    icons/48-apps-labplot.png [from: icons/48-apps-labplot2.png - 100% similarity]
R  +-    --    icons/512-application-x-labplot.png [from: icons/512-application-x-labplot2.png - 100% similarity]
R  +-    --    icons/512-apps-labplot.png [from: icons/512-apps-labplot2.png - 100% similarity]
R  +-    --    icons/64-application-x-labplot.png [from: icons/64-application-x-labplot2.png - 100% similarity]
R  +-    --    icons/64-apps-labplot.png [from: icons/64-apps-labplot2.png - 100% similarity]
M  +12   -12   icons/CMakeLists.txt
R  +-    --    icons/application-x-labplot.ico [from: icons/application-x-labplot2.ico - 100% similarity]
R  +-    --    icons/application-x-labplot.svg [from: icons/application-x-labplot2.svg - 099% similarity]
R  +-    --    icons/apps-labplot.svg [from: icons/apps-labplot2.svg - 100% similarity]
R  +-    --    icons/labplot.ico [from: icons/labplot2.ico - 100% similarity]
R  +-    --    icons/sc-apps-labplot.svgz [from: icons/sc-apps-labplot2.svgz - 100% similarity]
M  +12   -9    lib/CMakeLists.txt
R  +3    -3    org.kde.labplot.appdata.xml [from: org.kde.labplot2.appdata.xml - 099% similarity]
M  +4    -4    snapcraft.yaml
M  +16   -16   src/3rdparty/CMakeLists.txt
M  +83   -83   src/CMakeLists.txt
M  +3    -3    src/Info.plist
M  +4    -4    src/XmlMessages.sh
M  +3    -0    src/backend/cantorWorksheet/CantorWorksheet.cpp
M  +4    -4    src/kdefrontend/LabPlot.cpp
M  +1    -1    src/kdefrontend/MainWin.cpp
M  +3    -3    src/kdefrontend/PlotTemplateDialog.cpp
M  +2    -2    src/kdefrontend/TemplateHandler.cpp
R  +-    --    src/kdefrontend/labplot.ico [from: src/kdefrontend/labplot2.ico - 100% similarity]
A  +6    -0    src/kdefrontend/labplot.qrc
D  +0    -6    src/kdefrontend/labplot2.qrc
R  +0    -0    src/kdefrontend/labplotui.rc [from: src/kdefrontend/labplot2ui.rc - 100% similarity]
M  +2    -2    src/kdefrontend/welcomescreen/HelpList.qml
A  +36   -0    src/labplot.xml
D  +0    -36   src/labplot2.xml
R  +41   -41   src/org.kde.labplot.desktop [from: src/org.kde.labplot2.desktop - 088% similarity]
M  +2    -2    src/tools/TeXRenderer.cpp
M  +8    -8    tests/CMakeLists.txt
M  +1    -1    tests/CommonTest.cpp
M  +1    -1    tests/analysis/convolution/CMakeLists.txt
M  +1    -1    tests/analysis/correlation/CMakeLists.txt
M  +1    -1    tests/analysis/differentiation/CMakeLists.txt
M  +1    -1    tests/analysis/fit/CMakeLists.txt
M  +1    -1    tests/analysis/fourier/CMakeLists.txt
M  +1    -1    tests/analysis/hilberttransform/CMakeLists.txt
M  +1    -1    tests/analysis/integration/CMakeLists.txt
M  +1    -1    tests/analysis/interpolation/CMakeLists.txt
M  +1    -1    tests/analysis/smooth/CMakeLists.txt
M  +3    -3    tests/backend/Axis/CMakeLists.txt
M  +1    -1    tests/backend/BarPlot/CMakeLists.txt
M  +1    -1    tests/backend/Column/CMakeLists.txt
M  +1    -1    tests/backend/Datapicker/CMakeLists.txt
M  +1    -1    tests/backend/InfoElement/CMakeLists.txt
M  +1    -1    tests/backend/Parser/CMakeLists.txt
M  +1    -1    tests/backend/Range/CMakeLists.txt
M  +1    -1    tests/backend/Retransform/CMakeLists.txt
M  +1    -1    tests/backend/TextLabel/CMakeLists.txt
M  +2    -2    tests/backend/Worksheet/CMakeLists.txt
M  +2    -2    tests/backend/XYCurve/CMakeLists.txt
M  +1    -1    tests/backend/core/CMakeLists.txt
M  +2    -2    tests/backend/gsl/CMakeLists.txt
M  +1    -1    tests/cartesianplot/CMakeLists.txt
M  +1    -1    tests/cartesianplot/plots/statisticalplots/CMakeLists.txt
M  +1    -1    tests/commonfrontend/widgets/CMakeLists.txt
M  +1    -1    tests/commonfrontend/widgets/SpinBoxTest.h
M  +1    -1    tests/import_export/ASCII/CMakeLists.txt
M  +1    -1    tests/import_export/Binary/CMakeLists.txt
M  +1    -1    tests/import_export/CAN/CMakeLists.txt
M  +1    -1    tests/import_export/Datasets/CMakeLists.txt
M  +1    -1    tests/import_export/FITS/CMakeLists.txt
M  +1    -1    tests/import_export/HDF5/CMakeLists.txt
M  +1    -1    tests/import_export/JSON/CMakeLists.txt
M  +1    -1    tests/import_export/MCAP/CMakeLists.txt
M  +1    -1    tests/import_export/MQTT/CMakeLists.txt
M  +1    -1    tests/import_export/Matio/CMakeLists.txt
M  +1    -1    tests/import_export/NetCDF/CMakeLists.txt
M  +1    -1    tests/import_export/Ods/CMakeLists.txt
M  +1    -1    tests/import_export/Project/CMakeLists.txt
M  +1    -1    tests/import_export/ROOT/CMakeLists.txt
M  +1    -1    tests/import_export/ReadStat/CMakeLists.txt
M  +1    -1    tests/import_export/SQL/CMakeLists.txt
M  +2    -2    tests/import_export/Spice/CMakeLists.txt
M  +1    -1    tests/import_export/XLSX/CMakeLists.txt
M  +1    -1    tests/livedata/CMakeLists.txt
M  +2    -2    tests/matrix/CMakeLists.txt
M  +3    -3    tests/multirange/CMakeLists.txt
M  +1    -1    tests/notebook/CMakeLists.txt
M  +1    -1    tests/nsl/baseline/CMakeLists.txt
M  +1    -1    tests/nsl/dft/CMakeLists.txt
M  +1    -1    tests/nsl/diff/CMakeLists.txt
M  +1    -1    tests/nsl/filter/CMakeLists.txt
M  +1    -1    tests/nsl/fit/CMakeLists.txt
M  +1    -1    tests/nsl/geom/CMakeLists.txt
M  +1    -1    tests/nsl/int/CMakeLists.txt
M  +1    -1    tests/nsl/math/CMakeLists.txt
M  +1    -1    tests/nsl/peak/CMakeLists.txt
M  +2    -2    tests/nsl/sf/CMakeLists.txt
M  +1    -1    tests/nsl/smooth/CMakeLists.txt
M  +1    -1    tests/nsl/stats/CMakeLists.txt
M  +3    -3    tests/spreadsheet/CMakeLists.txt

https://invent.kde.org/education/labplot/-/commit/1768563764ff88e7193d9d4100bb7d5e502e029a

diff --git a/.flatpak-manifest.json b/.flatpak-manifest.json
index 26ffcb7518..1497347807 100644
--- a/.flatpak-manifest.json
+++ b/.flatpak-manifest.json
@@ -1,12 +1,12 @@
 {
-    "id": "org.kde.labplot2",
+    "id": "org.kde.labplot",
     "branch": "master",
     "runtime": "org.kde.Platform",
     "runtime-version": "5.15-23.08",
     "base": "io.qt.qtwebengine.BaseApp",
     "base-version": "5.15-23.08",
     "sdk": "org.kde.Sdk",
-    "command": "labplot2",
+    "command": "labplot",
     "tags": ["nightly"],
     "desktop-file-name-suffix": " (Nightly)",
     "finish-args": [
diff --git a/.gitlab-ci.yml b/.gitlab-ci.yml
index c8dbce6bbe..7d5b3b64f7 100644
--- a/.gitlab-ci.yml
+++ b/.gitlab-ci.yml
@@ -93,9 +93,6 @@ flatpak:
     - if: '$CI_COMMIT_REF_NAME == "master"'
       when: manual
       allow_failure: true
-  variables:
-    KDE_FLATPAK_MODULE_NAME: labplot2
-    KDE_FLATPAK_APP_ID: org.kde.${KDE_FLATPAK_MODULE_NAME}
 
 variables:
     QT_TEST_TIMEOUT_FUNCTION: "600"
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 8305d0fe4f..70ae052778 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -1,6 +1,6 @@
 # see https://community.kde.org/Policies/CMake_Coding_Style
 cmake_minimum_required(VERSION 3.17.0 FATAL_ERROR)
-project(labplot2 VERSION 2.11.80 LANGUAGES CXX C)
+project(labplot VERSION 2.11.80 LANGUAGES CXX C)
 
 set(CMAKE_C_STANDARD 99)
 set(CMAKE_C_STANDARD_REQUIRED ON)
@@ -228,7 +228,7 @@ endif()
 
 include_directories(${QDBUS_INCLUDE_DIRS} ${CMAKE_SOURCE_DIR} ${CMAKE_BINARY_DIR})
 set(CMAKE_MODULE_PATH ${CMAKE_SOURCE_DIR}/cmake ${CMAKE_MODULE_PATH})
-add_definitions(-DLVERSION=\"${labplot2_VERSION}\")
+add_definitions(-DLVERSION=\"${labplot_VERSION}\")
 add_definitions(-DCXX_COMPILER=\"${CMAKE_CXX_COMPILER_ID}\ ${CMAKE_CXX_COMPILER_VERSION}\")
 add_definitions(-DCXX_COMPILER_FLAGS=\"${CMAKE_CXX_FLAGS}\")
 set(BUILD_SHARED_LIBS true)
@@ -717,7 +717,7 @@ else()
     message(STATUS "SDK build DISABLED")
 endif()
 
-install(FILES org.kde.labplot2.appdata.xml DESTINATION ${KDE_INSTALL_METAINFODIR})
+install(FILES org.kde.labplot.appdata.xml DESTINATION ${KDE_INSTALL_METAINFODIR})
 
 # clang format
 #file(GLOB_RECURSE ALL_CLANG_FORMAT_SOURCE_FILES *.cpp *.h *.c)
diff --git a/ChangeLog b/ChangeLog
index bbe44f922c..b969e62a98 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -12,6 +12,10 @@ New features:
 Bug fixes:
 	* Fix crash selecting "cell" from function list in function dialog
 
+Internal:
+	* use name LabPlot/labplot consistenly (renamed Labplot2/labplot2)
+
+
 -----2.11.1 (16.07.2024) -----
 Bug fixes:
 	* Improve ODS support (selected platforms only)
diff --git a/admin/README.release b/admin/README.release
index 733f7ac84c..dd4778a954 100644
--- a/admin/README.release
+++ b/admin/README.release
@@ -2,9 +2,9 @@
 * string freeze (14 days before recommended)
 * Update splash screen src/kdefrontend/splash.png
 * in master (+ cherry-pick to release/2.8)
-	* add release with date in org.kde.labplot2.appdata.xml
+	* add release with date in org.kde.labplot.appdata.xml
 	* Set release date in Changelog
-* (master|release/2.8) CMakeLists.txt: project(labplot2 VERSION 2.8.0 LANGUAGES CXX C)
+* (master|release/2.8) CMakeLists.txt: project(labplot VERSION 2.8.0 LANGUAGES CXX C)
 
 ------------------------------------------------------------
 
@@ -49,7 +49,7 @@ git branch --set-upstream-to=origin/release/2.8
 * Use the following template for the ticket (generated by releaseme; flat target):
 
 ###########
-Please add 2.8.0 to bugs.kde.org product LabPlot2
+Please add 2.8.0 to bugs.kde.org product LabPlot
 
 Target: stable/labplot/
 
@@ -75,7 +75,7 @@ e8afdecbd79247da28278312d07a31b2bc111b15  labplot-2.8.0.tar.xz.sig
 
 
 8. When tarball is available:
-* .0: update release in master to 2.8.80: CMakeLists.txt: project(labplot2 VERSION 2.8.80 LANGUAGES CXX C)
+* .0: update release in master to 2.8.80: CMakeLists.txt: project(labplot VERSION 2.8.80 LANGUAGES CXX C)
 * Upload tarball and packages to https://sourceforge.net/projects/labplot/ [scp] + Update default downloads
 * Update Flatpak @ https://github.com/flathub/org.kde.labplot2/blob/master/org.kde.labplot2.json
 * Update blueprint @ https://invent.kde.org/packaging/craft-blueprints-kde/-/tree/master/kde/applications/labplot/labplot.py
diff --git a/doc/CMakeLists.txt b/doc/CMakeLists.txt
index d07ce0392c..fa9cf4f2e2 100644
--- a/doc/CMakeLists.txt
+++ b/doc/CMakeLists.txt
@@ -2,4 +2,4 @@
 #
 #
 kdoctools_create_handbook(index.docbook INSTALL_DESTINATION ${KDE_INSTALL_DOCBUNDLEDIR}/en SUBDIR ${PROJECT_NAME})
-kdoctools_create_manpage(man-labplot2.1.docbook 1 INSTALL_DESTINATION ${KDE_INSTALL_MANDIR})
+kdoctools_create_manpage(man-labplot.1.docbook 1 INSTALL_DESTINATION ${KDE_INSTALL_MANDIR})
diff --git a/doc/man-labplot2.1.docbook b/doc/man-labplot.1.docbook
similarity index 90%
rename from doc/man-labplot2.1.docbook
rename to doc/man-labplot.1.docbook
index e0600819e6..a07c54568d 100644
--- a/doc/man-labplot2.1.docbook
+++ b/doc/man-labplot.1.docbook
@@ -16,18 +16,18 @@
 </refentryinfo>
 
 <refmeta>
-<refentrytitle><command>labplot2</command></refentrytitle>
+<refentrytitle><command>labplot</command></refentrytitle>
 <manvolnum>1</manvolnum>
 </refmeta>
 
 <refnamediv>
-<refname>labplot2</refname>
+<refname>labplot</refname>
 <refpurpose>an application by KDE for interactive graphing and analysis of scientific data.</refpurpose>
 </refnamediv>
 <!-- body begins here -->
 <refsynopsisdiv id='synopsis'>
 <cmdsynopsis>
-  <command>labplot2</command>
+  <command>labplot</command>
     <arg choice="opt"><replaceable>LabPlot options</replaceable></arg>
     <arg choice="opt"><replaceable>file</replaceable></arg>
 </cmdsynopsis>
@@ -42,14 +42,14 @@
     Its features include 2D and 3D data and function plotting, easy editing of plots, analysis of data and functions, support for different worksheets using MDI and LabPlot project files.
 </para>
 <para>
-    Note that LabPlot is called using <command>labplot2</command>.
+    Note that LabPlot is called using <command>labplot</command>.
 </para>
 
 </refsect1>
 
 <refsect1 id="options"><title>LabPlot options</title>
 <para>
-    For a full summary of generic options, run <userinput><command>labplot2</command> <parameter>--help</parameter></userinput>.
+    For a full summary of generic options, run <userinput><command>labplot</command> <parameter>--help</parameter></userinput>.
 </para>
 
 <variablelist>
@@ -86,10 +86,10 @@
 <simplelist>
 <member>Full user documentation is available through the KDE Help Centre.
 You can also enter the URL <ulink
-url="help:/labplot2">help:/labplot2</ulink>
+url="help:/labplot">help:/labplot</ulink>
 (either enter this <acronym>URL</acronym> into &dolphin;, or run
 <userinput><command>khelpcenter</command>
-<parameter>help:/labplot2</parameter></userinput>).</member>
+<parameter>help:/labplot</parameter></userinput>).</member>
 <member>kf5options(7)</member>
 <member>qt5options(7)</member>
 <member>There is also further information available at
@@ -99,7 +99,7 @@ url="help:/labplot2">help:/labplot2</ulink>
 
 <refsect1 id="authors"><title>Authors</title>
 <para>
-    LabPlot2 was written by
+    LabPlot was written by
 </para>
 <simplelist>
     <member>Stefan Gerlach &lt;[email protected]&gt;,</member>
diff --git a/icons/128-application-x-labplot2.png b/icons/128-application-x-labplot.png
similarity index 100%
rename from icons/128-application-x-labplot2.png
rename to icons/128-application-x-labplot.png
diff --git a/icons/128-apps-labplot2.png b/icons/128-apps-labplot.png
similarity index 100%
rename from icons/128-apps-labplot2.png
rename to icons/128-apps-labplot.png
diff --git a/icons/150-apps-labplot2.png b/icons/150-apps-labplot.png
similarity index 100%
rename from icons/150-apps-labplot2.png
rename to icons/150-apps-labplot.png
diff --git a/icons/16-application-x-labplot2.png b/icons/16-application-x-labplot.png
similarity index 100%
rename from icons/16-application-x-labplot2.png
rename to icons/16-application-x-labplot.png
diff --git a/icons/16-apps-labplot2.png b/icons/16-apps-labplot.png
similarity index 100%
rename from icons/16-apps-labplot2.png
rename to icons/16-apps-labplot.png
diff --git a/icons/22-application-x-labplot2.png b/icons/22-application-x-labplot.png
similarity index 100%
rename from icons/22-application-x-labplot2.png
rename to icons/22-application-x-labplot.png
diff --git a/icons/22-apps-labplot2.png b/icons/22-apps-labplot.png
similarity index 100%
rename from icons/22-apps-labplot2.png
rename to icons/22-apps-labplot.png
diff --git a/icons/256-application-x-labplot2.png b/icons/256-application-x-labplot.png
similarity index 100%
rename from icons/256-application-x-labplot2.png
rename to icons/256-application-x-labplot.png
diff --git a/icons/256-apps-labplot2.png b/icons/256-apps-labplot.png
similarity index 100%
rename from icons/256-apps-labplot2.png
rename to icons/256-apps-labplot.png
diff --git a/icons/310-apps-labplot2.png b/icons/310-apps-labplot.png
similarity index 100%
rename from icons/310-apps-labplot2.png
rename to icons/310-apps-labplot.png
diff --git a/icons/32-application-x-labplot2.png b/icons/32-application-x-labplot.png
similarity index 100%
rename from icons/32-application-x-labplot2.png
rename to icons/32-application-x-labplot.png
diff --git a/icons/32-apps-labplot2.png b/icons/32-apps-labplot.png
similarity index 100%
rename from icons/32-apps-labplot2.png
rename to icons/32-apps-labplot.png
diff --git a/icons/44-apps-labplot2.png b/icons/44-apps-labplot.png
similarity index 100%
rename from icons/44-apps-labplot2.png
rename to icons/44-apps-labplot.png
diff --git a/icons/48-application-x-labplot2.png b/icons/48-application-x-labplot.png
similarity index 100%
rename from icons/48-application-x-labplot2.png
rename to icons/48-application-x-labplot.png
diff --git a/icons/48-apps-labplot2.png b/icons/48-apps-labplot.png
similarity index 100%
rename from icons/48-apps-labplot2.png
rename to icons/48-apps-labplot.png
diff --git a/icons/512-application-x-labplot2.png b/icons/512-application-x-labplot.png
similarity index 100%
rename from icons/512-application-x-labplot2.png
rename to icons/512-application-x-labplot.png
diff --git a/icons/512-apps-labplot2.png b/icons/512-apps-labplot.png
similarity index 100%
rename from icons/512-apps-labplot2.png
rename to icons/512-apps-labplot.png
diff --git a/icons/64-application-x-labplot2.png b/icons/64-application-x-labplot.png
similarity index 100%
rename from icons/64-application-x-labplot2.png
rename to icons/64-application-x-labplot.png
diff --git a/icons/64-apps-labplot2.png b/icons/64-apps-labplot.png
similarity index 100%
rename from icons/64-apps-labplot2.png
rename to icons/64-apps-labplot.png
diff --git a/icons/CMakeLists.txt b/icons/CMakeLists.txt
index 3085984dea..b10080a959 100644
--- a/icons/CMakeLists.txt
+++ b/icons/CMakeLists.txt
@@ -1,15 +1,15 @@
 ecm_install_icons(
 ICONS
-128-apps-labplot2.png
-150-apps-labplot2.png
-16-apps-labplot2.png
-22-apps-labplot2.png
-256-apps-labplot2.png
-310-apps-labplot2.png
-32-apps-labplot2.png
-44-apps-labplot2.png
-48-apps-labplot2.png
-512-apps-labplot2.png
-64-apps-labplot2.png
-sc-apps-labplot2.svgz
+128-apps-labplot.png
+150-apps-labplot.png
+16-apps-labplot.png
+22-apps-labplot.png
+256-apps-labplot.png
+310-apps-labplot.png
+32-apps-labplot.png
+44-apps-labplot.png
+48-apps-labplot.png
+512-apps-labplot.png
+64-apps-labplot.png
+sc-apps-labplot.svgz
 DESTINATION ${KDE_INSTALL_ICONDIR}/)
diff --git a/icons/application-x-labplot2.ico b/icons/application-x-labplot.ico
similarity index 100%
rename from icons/application-x-labplot2.ico
rename to icons/application-x-labplot.ico
diff --git a/icons/application-x-labplot2.svg b/icons/application-x-labplot.svg
similarity index 99%
rename from icons/application-x-labplot2.svg
rename to icons/application-x-labplot.svg
index 904a989f40..13edd30ab3 100644
Binary files a/icons/application-x-labplot2.svg and b/icons/application-x-labplot.svg differ
diff --git a/icons/apps-labplot2.svg b/icons/apps-labplot.svg
similarity index 100%
rename from icons/apps-labplot2.svg
rename to icons/apps-labplot.svg
diff --git a/icons/labplot2.ico b/icons/labplot.ico
similarity index 100%
rename from icons/labplot2.ico
rename to icons/labplot.ico
diff --git a/icons/sc-apps-labplot2.svgz b/icons/sc-apps-labplot.svgz
similarity index 100%
rename from icons/sc-apps-labplot2.svgz
rename to icons/sc-apps-labplot.svgz
diff --git a/lib/CMakeLists.txt b/lib/CMakeLists.txt
index 3a43c980c9..75a6e21a8f 100644
--- a/lib/CMakeLists.txt
+++ b/lib/CMakeLists.txt
@@ -220,10 +220,13 @@ add_definitions(-DQT_DISABLE_DEPRECATED_BEFORE=0x50500)
 #endif ()
 
 # dynamic library
-add_library(labplot ${GUI_SOURCES} ${BACKEND_SOURCES} ${NSL_SOURCES} ${COMMONFRONTEND_SOURCES} ${TOOLS_SOURCES} ${GENERATED_SOURCES} ${QTMOC_HDRS})
-generate_export_header(labplot)
+add_library(liblabplot ${GUI_SOURCES} ${BACKEND_SOURCES} ${NSL_SOURCES} ${COMMONFRONTEND_SOURCES} ${TOOLS_SOURCES} ${GENERATED_SOURCES} ${QTMOC_HDRS})
+# name it liblabplot, not libliblabplot
+set_property(TARGET liblabplot PROPERTY OUTPUT_NAME labplot)
+# generate labplot_export.h + LABPLOT_EXPORT
+generate_export_header(liblabplot BASE_NAME labplot)
 
-target_link_libraries(labplot
+target_link_libraries(liblabplot
     KF${KF_MAJOR_VERSION}::Archive
     KF${KF_MAJOR_VERSION}::ConfigCore
     KF${KF_MAJOR_VERSION}::ConfigWidgets
@@ -244,28 +247,28 @@ target_link_libraries(labplot
     ${LIBCERF_LIBRARIES})
 
 if(Discount_FOUND)
-    target_link_libraries(labplot Discount::Lib)
+    target_link_libraries(liblabplot Discount::Lib)
 endif()
 
 if(ENABLE_LIBORIGIN)
     if(LIBORIGIN_FOUND)
-        target_link_libraries(labplot ${LIBORIGIN_LIBRARIES})
+        target_link_libraries(liblabplot ${LIBORIGIN_LIBRARIES})
     else()
-        target_link_libraries(labplot liborigin-static)
+        target_link_libraries(liblabplot liborigin-static)
     endif()
 endif()
 
 if(RECENT_CANTOR)
     # KFX::Service, KFX::Parts is optional but probably required by Cantor
-    target_link_libraries(labplot Cantor::cantorlibs KF${KF_MAJOR_VERSION}::Service KF${KF_MAJOR_VERSION}::Parts)
+    target_link_libraries(liblabplot Cantor::cantorlibs KF${KF_MAJOR_VERSION}::Service KF${KF_MAJOR_VERSION}::Parts)
 endif()
 
 if(WIN32)
-    target_link_libraries(labplot ${PSAPI})
+    target_link_libraries(liblabplot ${PSAPI})
 endif()
 
 ############## installation ################################
-install(TARGETS labplot DESTINATION ${KDE_INSTALL_TARGETS_DEFAULT_ARGS})
+install(TARGETS liblabplot DESTINATION ${KDE_INSTALL_TARGETS_DEFAULT_ARGS})
 
 
 install(FILES ${CMAKE_CURRENT_BINARY_DIR}/labplot_export.h  DESTINATION ${KDE_INSTALL_INCLUDEDIR}/labplot COMPONENT Devel)
diff --git a/org.kde.labplot2.appdata.xml b/org.kde.labplot.appdata.xml
similarity index 99%
rename from org.kde.labplot2.appdata.xml
rename to org.kde.labplot.appdata.xml
index 44571b9bea..a491b4d153 100644
--- a/org.kde.labplot2.appdata.xml
+++ b/org.kde.labplot.appdata.xml
@@ -1,10 +1,10 @@
 <?xml version="1.0" encoding="utf-8"?>
 <component type="desktop">
-  <id>org.kde.labplot2.desktop</id>
+  <id>org.kde.labplot.desktop</id>
   <metadata_license>CC0-1.0</metadata_license>
   <project_license>GPL-2.0+</project_license>
   <developer_name translate="no">KDE</developer_name>
-  <launchable type="desktop-id">org.kde.labplot2.desktop</launchable>
+  <launchable type="desktop-id">org.kde.labplot.desktop</launchable>
   <name>LabPlot</name>
   <name xml:lang="ar">معمل الرسم</name>
   <name xml:lang="bs">LabPlot</name>
@@ -442,7 +442,7 @@
   </screenshots>
   <project_group>KDE</project_group>
   <provides>
-    <binary>labplot2</binary>
+    <binary>labplot</binary>
   </provides>
   <content_rating type="oars-1.1"/>
   <releases>
diff --git a/snapcraft.yaml b/snapcraft.yaml
index f1636ef05b..8e1140af2e 100644
--- a/snapcraft.yaml
+++ b/snapcraft.yaml
@@ -12,9 +12,9 @@ apps:
     labplot:
         # extensions:
         # - kde-neon
-        common-id: org.kde.labplot2.desktop
-        desktop: usr/share/applications/org.kde.labplot2.desktop
-        command: usr/bin/labplot2
+        common-id: org.kde.labplot.desktop
+        desktop: usr/share/applications/org.kde.labplot.desktop
+        command: usr/bin/labplot
         plugs:
         - home
         - desktop
@@ -145,7 +145,7 @@ parts:
         - kde-neon
         - qxlsx
         parse-info:
-        - usr/share/metainfo/org.kde.labplot2.appdata.xml
+        - usr/share/metainfo/org.kde.labplot.appdata.xml
         plugin: cmake
         build-packages:
         - libqt5mqtt-dev
diff --git a/src/3rdparty/CMakeLists.txt b/src/3rdparty/CMakeLists.txt
index 5cc34c9b18..45a735db27 100644
--- a/src/3rdparty/CMakeLists.txt
+++ b/src/3rdparty/CMakeLists.txt
@@ -98,16 +98,16 @@ if(ENABLE_VECTOR_BLF)
       endif()
       # headerfiles of the projects are referring to <libdbc/someheader.h> and therefore
       # the path must be added
-      target_include_directories(labplot2backendlib PUBLIC ${dbc_parser_cpp_SOURCE_DIR}/include)
-      target_link_libraries(labplot2backendlib dbc)
-      target_compile_definitions(labplot2backendlib PRIVATE HAVE_DBC_PARSER)
-      target_compile_definitions(labplot2lib PUBLIC HAVE_DBC_PARSER)
+      target_include_directories(labplotbackendlib PUBLIC ${dbc_parser_cpp_SOURCE_DIR}/include)
+      target_link_libraries(labplotbackendlib dbc)
+      target_compile_definitions(labplotbackendlib PRIVATE HAVE_DBC_PARSER)
+      target_compile_definitions(labplotlib PUBLIC HAVE_DBC_PARSER)
   else ()
     pkg_check_modules(dbc IMPORTED_TARGET GLOBAL dbc)
     if(dbc_FOUND)
-        target_link_libraries(labplot2backendlib PkgConfig::dbc)
-        target_compile_definitions(labplot2backendlib PRIVATE HAVE_DBC_PARSER)
-        target_compile_definitions(labplot2lib PUBLIC HAVE_DBC_PARSER)
+        target_link_libraries(labplotbackendlib PkgConfig::dbc)
+        target_compile_definitions(labplotbackendlib PRIVATE HAVE_DBC_PARSER)
+        target_compile_definitions(labplotlib PUBLIC HAVE_DBC_PARSER)
     endif()
   endif()
   
@@ -129,16 +129,16 @@ if(ENABLE_VECTOR_BLF)
           ${vector_blf_BINARY_DIR}/src) # config.h is in there
       target_include_directories(Vector_BLF PUBLIC ${vector_blf_SOURCE_DIR}/src
                           ${vector_blf_BINARY_DIR}/src) # config.h is in there
-      target_link_libraries(labplot2backendlib Vector_BLF)
-      target_compile_definitions(labplot2backendlib PRIVATE HAVE_VECTOR_BLF)
-      target_compile_definitions(labplot2lib PUBLIC HAVE_VECTOR_BLF)
+      target_link_libraries(labplotbackendlib Vector_BLF)
+      target_compile_definitions(labplotbackendlib PRIVATE HAVE_VECTOR_BLF)
+      target_compile_definitions(labplotlib PUBLIC HAVE_VECTOR_BLF)
       add_definitions (-DHAVE_VECTOR_BLF)
   else()
     pkg_check_modules(Vector_BLF IMPORTED_TARGET GLOBAL Vector_BLF)
     if(Vector_BLF_FOUND)
-        target_link_libraries(labplot2backendlib PkgConfig::Vector_BLF)
-        target_compile_definitions(labplot2backendlib PRIVATE HAVE_VECTOR_BLF)
-        target_compile_definitions(labplot2lib PUBLIC HAVE_VECTOR_BLF)
+        target_link_libraries(labplotbackendlib PkgConfig::Vector_BLF)
+        target_compile_definitions(labplotbackendlib PRIVATE HAVE_VECTOR_BLF)
+        target_compile_definitions(labplotlib PUBLIC HAVE_VECTOR_BLF)
         add_definitions (-DHAVE_VECTOR_BLF)
     endif()
   endif()
@@ -164,7 +164,7 @@ if(LOCAL_QT_ADVANCED_DOCK_DOWNLOAD)
 elseif(LOCAL_QT_ADVANCED_DOCK_COPY)
     # https://cmake.org/cmake/help/latest/variable/CMAKE_PROJECT_INCLUDE.html
     set(CMAKE_PROJECT_QtADS_INCLUDE "${CMAKE_CURRENT_SOURCE_DIR}/cmake/QtADS_config.cmake")
-    set(ADS_VERSION ${labplot2_VERSION})
+    set(ADS_VERSION ${labplot_VERSION})
     add_subdirectory(Qt-Advanced-Docking-System EXCLUDE_FROM_ALL)
 endif()
 
@@ -175,7 +175,7 @@ if(LOCAL_MCAP_DOWNLOAD)
     )
     FetchContent_MakeAvailable(mcap)
     #set(_mcap_include_dir ${mcap_SOURCE_DIR}/cpp/mcap/include)
-    target_include_directories(labplot2backendlib PUBLIC ${mcap_SOURCE_DIR}/cpp/mcap/include)
+    target_include_directories(labplotbackendlib PUBLIC ${mcap_SOURCE_DIR}/cpp/mcap/include)
 else ()
-    target_include_directories(labplot2backendlib PRIVATE ${CMAKE_CURRENT_SOURCE_DIR}/mcap/include)
+    target_include_directories(labplotbackendlib PRIVATE ${CMAKE_CURRENT_SOURCE_DIR}/mcap/include)
 endif()
diff --git a/src/CMakeLists.txt b/src/CMakeLists.txt
index dd55ffb18a..b706e27b67 100644
--- a/src/CMakeLists.txt
+++ b/src/CMakeLists.txt
@@ -170,7 +170,7 @@ if(APPLE)
 endif()
 
 set(GUI_QRC
-    ${KDEFRONTEND_DIR}/labplot2.qrc
+    ${KDEFRONTEND_DIR}/labplot.qrc
 )
 
 set(UI_SOURCES
@@ -542,9 +542,9 @@ set(GENERATED_SOURCES
 )
 
 ##############################################################################
-INCLUDE_DIRECTORIES(. ${BACKEND_DIR}/gsl ${GSL_INCLUDE_DIR} )
-set(LABPLOT_SRCS ${GUI_SOURCES} )
-ki18n_wrap_ui(LABPLOT_SRCS ${UI_SOURCES} )
+INCLUDE_DIRECTORIES(. ${BACKEND_DIR}/gsl ${GSL_INCLUDE_DIR})
+set(LABPLOT_SRCS ${GUI_SOURCES})
+ki18n_wrap_ui(LABPLOT_SRCS ${UI_SOURCES})
 # see also QT_MIN_VERSION in CMakeLists.txt
 add_definitions(-DQT_DISABLE_DEPRECATED_BEFORE=0x50700)
 #if(QT_MAJOR_VERSION MATCHES 5 AND QT_MINOR_VERSION MATCHES 15)
@@ -554,29 +554,29 @@ add_definitions(-DQT_DISABLE_DEPRECATED_BEFORE=0x50700)
 #add_definitions(-DQT_DISABLE_DEPRECATED_BEFORE=0x50F00)
 
 # static library
-add_library(labplot2nsllib STATIC ${NSL_SOURCES} )
-add_library(labplot2backendlib STATIC ${BACKEND_SOURCES} ${UI_SOURCES} ${BACKEND_TOOLS_SOURCES} ${GENERATED_SOURCES} )
-add_library(labplot2lib STATIC ${LABPLOT_SRCS} ${CANTOR_SOURCES} ${DATASOURCES_SOURCES} ${COMMONFRONTEND_SOURCES} ${TOOLS_SOURCES} ${QTMOC_HDRS} )
+add_library(labplotnsllib STATIC ${NSL_SOURCES})
+add_library(labplotbackendlib STATIC ${BACKEND_SOURCES} ${UI_SOURCES} ${BACKEND_TOOLS_SOURCES} ${GENERATED_SOURCES})
+add_library(labplotlib STATIC ${LABPLOT_SRCS} ${CANTOR_SOURCES} ${DATASOURCES_SOURCES} ${COMMONFRONTEND_SOURCES} ${TOOLS_SOURCES} ${QTMOC_HDRS})
 # set_property(TARGET ${objlib} PROPERTY POSITION_INDEPENDENT_CODE 1)
-target_include_directories(labplot2backendlib PUBLIC ${COMMONFRONTEND_DIR}/widgets) # so that the MOC finds numberSpinbox.h
-target_include_directories(labplot2lib PUBLIC ${COMMONFRONTEND_DIR}/widgets) # so that the MOC finds numberSpinbox.h
+target_include_directories(labplotbackendlib PUBLIC ${COMMONFRONTEND_DIR}/widgets) # so that the MOC finds numberSpinbox.h
+target_include_directories(labplotlib PUBLIC ${COMMONFRONTEND_DIR}/widgets) # so that the MOC finds numberSpinbox.h
 
 # add system QADS include path
 if(qt${QT_VERSION_MAJOR}advanceddocking_FOUND)
     get_target_property(QADS_INCLUDES ads::qt${QT_VERSION_MAJOR}advanceddocking INTERFACE_INCLUDE_DIRECTORIES)
     get_target_property(QADS_LIBRARIES ads::qt${QT_VERSION_MAJOR}advanceddocking INTERFACE_LINK_LIBRARIES)
     message(STATUS "QADS Found LINK_LIBRARIES: ${QADS_LIBRARIES} INCLUDES: ${QADS_INCLUDES}")
-    target_include_directories(labplot2backendlib PRIVATE ${QADS_INCLUDES} )
-    target_include_directories(labplot2lib PRIVATE ${QADS_INCLUDES} )
+    target_include_directories(labplotbackendlib PRIVATE ${QADS_INCLUDES})
+    target_include_directories(labplotlib PRIVATE ${QADS_INCLUDES})
 endif()
-target_compile_definitions(labplot2backendlib PRIVATE ${LABPLOT_COMPILE_DEFINITIONS})
-target_compile_definitions(labplot2lib PRIVATE ${LABPLOT_COMPILE_DEFINITIONS})
+target_compile_definitions(labplotbackendlib PRIVATE ${LABPLOT_COMPILE_DEFINITIONS})
+target_compile_definitions(labplotlib PRIVATE ${LABPLOT_COMPILE_DEFINITIONS})
 
-target_link_libraries(labplot2nsllib
+target_link_libraries(labplotnsllib
     Qt${QT_MAJOR_VERSION}::Core
     Qt${QT_MAJOR_VERSION}::Widgets    # QApplication
 )
-target_link_libraries(labplot2backendlib
+target_link_libraries(labplotbackendlib
     Qt${QT_MAJOR_VERSION}::Core
     Qt${QT_MAJOR_VERSION}::Gui    # QColor
     Qt${QT_MAJOR_VERSION}::Widgets    # QApplication
@@ -600,8 +600,8 @@ target_link_libraries(labplot2backendlib
     ${LIBCERF_LIBRARIES}
     ${MATIO_LIBRARIES}
     ads::qt${QT_VERSION_MAJOR}advanceddocking
-    )
-target_link_libraries(labplot2lib
+)
+target_link_libraries(labplotlib
     Qt${QT_MAJOR_VERSION}::Svg
     Qt${QT_MAJOR_VERSION}::Sql
     Qt${QT_MAJOR_VERSION}::PrintSupport    # QPrinter
@@ -620,127 +620,127 @@ target_link_libraries(labplot2lib
     KF${KF_MAJOR_VERSION}::TextWidgets    # KTextEdit
     ${Poppler_LIBRARIES}
     ads::qt${QT_VERSION_MAJOR}advanceddocking
-    )
+)
 
 if(Qt${QT_MAJOR_VERSION}SerialPort_FOUND)
-    target_link_libraries(labplot2backendlib Qt${QT_MAJOR_VERSION}::SerialPort )
-    target_link_libraries(labplot2lib Qt${QT_MAJOR_VERSION}::SerialPort )
+    target_link_libraries(labplotbackendlib Qt${QT_MAJOR_VERSION}::SerialPort)
+    target_link_libraries(labplotlib Qt${QT_MAJOR_VERSION}::SerialPort)
 endif()
 if(Qt${QT_MAJOR_VERSION}Mqtt_FOUND)
-    target_link_libraries(labplot2backendlib Qt${QT_MAJOR_VERSION}::Mqtt )
-    target_link_libraries(labplot2lib Qt${QT_MAJOR_VERSION}::Mqtt )
+    target_link_libraries(labplotbackendlib Qt${QT_MAJOR_VERSION}::Mqtt)
+    target_link_libraries(labplotlib Qt${QT_MAJOR_VERSION}::Mqtt)
 endif()
 if(KF${KF_MAJOR_VERSION}SyntaxHighlighting_FOUND)
-    target_link_libraries(labplot2lib KF${KF_MAJOR_VERSION}::SyntaxHighlighting )
+    target_link_libraries(labplotlib KF${KF_MAJOR_VERSION}::SyntaxHighlighting)
 endif()
 if(KUserFeedback_FOUND)
-    target_link_libraries(labplot2lib KUserFeedbackWidgets )
+    target_link_libraries(labplotlib KUserFeedbackWidgets)
 endif()
 if(KUserFeedbackQt6_FOUND)
-    target_link_libraries(labplot2lib KUserFeedbackCoreQt6 KUserFeedbackWidgetsQt6 )
+    target_link_libraries(labplotlib KUserFeedbackCoreQt6 KUserFeedbackWidgetsQt6)
 endif()
 if(Discount_FOUND)
-    target_link_libraries(labplot2lib Discount::Lib )
+    target_link_libraries(labplotlib Discount::Lib)
 endif()
 if(Orcus_FOUND)
-    target_link_libraries(labplot2lib ${Orcus_LIBRARIES} ${Ixion_LIBRARY} )
+    target_link_libraries(labplotlib ${Orcus_LIBRARIES} ${Ixion_LIBRARY})
 endif()
 # TODO: KF6::NewStuff not found even though KF6NewStuff_FOUND
 if(KF5NewStuff_FOUND)
-    target_link_libraries(labplot2lib KF5::NewStuff )
+    target_link_libraries(labplotlib KF5::NewStuff)
 endif()
 if(KF${KF_MAJOR_VERSION}Purpose_FOUND)
-    target_link_libraries(labplot2lib KF${KF_MAJOR_VERSION}::PurposeWidgets )
+    target_link_libraries(labplotlib KF${KF_MAJOR_VERSION}::PurposeWidgets)
 endif()
 if(ZSTD_FOUND)
-        target_link_libraries(labplot2backendlib ${ZSTD_LIBRARIES})
+        target_link_libraries(labplotbackendlib ${ZSTD_LIBRARIES})
 endif()
 
 if(RECENT_CANTOR)
     # KFX::Service, KFX::Parts is optional but probably required by Cantor
-    target_link_libraries(labplot2backendlib Cantor::cantorlibs KF${KF_MAJOR_VERSION}::Service KF${KF_MAJOR_VERSION}::Parts )
-    target_link_libraries(labplot2lib Cantor::cantorlibs KF${KF_MAJOR_VERSION}::Service KF${KF_MAJOR_VERSION}::Parts )
+    target_link_libraries(labplotbackendlib Cantor::cantorlibs KF${KF_MAJOR_VERSION}::Service KF${KF_MAJOR_VERSION}::Parts)
+    target_link_libraries(labplotlib Cantor::cantorlibs KF${KF_MAJOR_VERSION}::Service KF${KF_MAJOR_VERSION}::Parts)
 endif()
 
 if(ENABLE_READSTAT)
     # build before using
     if(BUILD_READSTAT)
-        add_dependencies(labplot2backendlib 3rdparty_readstat )
+        add_dependencies(labplotbackendlib 3rdparty_readstat)
     endif()
     # link system readstat with iconv
     if(READSTAT_FOUND)
         find_library(ICONV_LIBRARIES NAMES iconv libiconv libconv-2)
         if(ICONV_LIBRARIES)
-            target_link_libraries (labplot2backendlib ${ICONV_LIBRARIES})
+            target_link_libraries (labplotbackendlib ${ICONV_LIBRARIES})
         endif()
     endif()
-        target_link_libraries(labplot2backendlib ${READSTAT_LIBRARIES} ${ZLIB_LIBRARIES})
+        target_link_libraries(labplotbackendlib ${READSTAT_LIBRARIES} ${ZLIB_LIBRARIES})
 endif()
 
 if(ENABLE_XLSX)
     # build before use
     if(BUILD_QXLSX)
-        target_include_directories(labplot2backendlib PRIVATE "${CMAKE_CURRENT_SOURCE_DIR}/3rdparty/QXlsx/header")
-        add_dependencies(labplot2backendlib QXlsx)
-        target_include_directories(labplot2lib PRIVATE "${CMAKE_CURRENT_SOURCE_DIR}/3rdparty/QXlsx/header")
-        add_dependencies(labplot2lib QXlsx)
+        target_include_directories(labplotbackendlib PRIVATE "${CMAKE_CURRENT_SOURCE_DIR}/3rdparty/QXlsx/header")
+        add_dependencies(labplotbackendlib QXlsx)
+        target_include_directories(labplotlib PRIVATE "${CMAKE_CURRENT_SOURCE_DIR}/3rdparty/QXlsx/header")
+        add_dependencies(labplotlib QXlsx)
     endif()
 
     if(QXLSX_FOUND)
-        target_include_directories(labplot2backendlib PRIVATE ${QXLSX_INCLUDE_DIR})
-        target_include_directories(labplot2lib PRIVATE ${QXLSX_INCLUDE_DIR})
+        target_include_directories(labplotbackendlib PRIVATE ${QXLSX_INCLUDE_DIR})
+        target_include_directories(labplotlib PRIVATE ${QXLSX_INCLUDE_DIR})
     endif()
 
     if(QXLSX_FOUND OR BUILD_QXLSX)
-    target_link_libraries(labplot2backendlib QXlsx)
+    target_link_libraries(labplotbackendlib QXlsx)
     endif()
 endif()
 
 if(ENABLE_LIBORIGIN)
     if(LIBORIGIN_FOUND)
         # ifsystem headers are missing: use the provided
-        target_include_directories(labplot2backendlib PRIVATE ${LIBORIGIN_INCLUDE_DIR} "${CMAKE_CURRENT_SOURCE_DIR}/3rdparty/liborigin")
-        target_link_libraries(labplot2backendlib ${LIBORIGIN_LIBRARIES})
-        target_include_directories(labplot2lib PRIVATE ${LIBORIGIN_INCLUDE_DIR} "${CMAKE_CURRENT_SOURCE_DIR}/3rdparty/liborigin")
+        target_include_directories(labplotbackendlib PRIVATE ${LIBORIGIN_INCLUDE_DIR} "${CMAKE_CURRENT_SOURCE_DIR}/3rdparty/liborigin")
+        target_link_libraries(labplotbackendlib ${LIBORIGIN_LIBRARIES})
+        target_include_directories(labplotlib PRIVATE ${LIBORIGIN_INCLUDE_DIR} "${CMAKE_CURRENT_SOURCE_DIR}/3rdparty/liborigin")
     else() # own version
-        target_include_directories(labplot2backendlib PRIVATE "${CMAKE_CURRENT_SOURCE_DIR}/3rdparty/liborigin")
-        target_link_libraries(labplot2backendlib liborigin-static)
-        target_include_directories(labplot2lib PRIVATE "${CMAKE_CURRENT_SOURCE_DIR}/3rdparty/liborigin")
+        target_include_directories(labplotbackendlib PRIVATE "${CMAKE_CURRENT_SOURCE_DIR}/3rdparty/liborigin")
+        target_link_libraries(labplotbackendlib liborigin-static)
+        target_include_directories(labplotlib PRIVATE "${CMAKE_CURRENT_SOURCE_DIR}/3rdparty/liborigin")
     endif()
 endif()
 
 IF(LZ4_FOUND)
-    target_include_directories(labplot2backendlib PUBLIC ${LZ4_INCLUDE_DIR})
+    target_include_directories(labplotbackendlib PUBLIC ${LZ4_INCLUDE_DIR})
 endif()
 
 if(PSAPI)
-    target_link_libraries(labplot2lib ${PSAPI})
+    target_link_libraries(labplotlib ${PSAPI})
 endif()
 
 if(APPLE AND ENABLE_TOUCHBAR)
-    target_link_libraries(labplot2lib KDMacTouchBar)
+    target_link_libraries(labplotlib KDMacTouchBar)
 endif()
 
 
 # icons for the executable and project files on Windows and Mac OS X
 
 set(LABPLOT_ICONS
-    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/16-apps-labplot2.png
-    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/32-apps-labplot2.png
-    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/48-apps-labplot2.png
-    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/64-apps-labplot2.png
-    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/128-apps-labplot2.png
-    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/256-apps-labplot2.png
-    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/512-apps-labplot2.png
+    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/16-apps-labplot.png
+    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/32-apps-labplot.png
+    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/48-apps-labplot.png
+    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/64-apps-labplot.png
+    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/128-apps-labplot.png
+    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/256-apps-labplot.png
+    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/512-apps-labplot.png
 )
 set(LML_ICONS
-    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/16-application-x-labplot2.png
-    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/32-application-x-labplot2.png
-    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/48-application-x-labplot2.png
-    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/64-application-x-labplot2.png
-    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/128-application-x-labplot2.png
-    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/256-application-x-labplot2.png
-    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/512-application-x-labplot2.png
+    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/16-application-x-labplot.png
+    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/32-application-x-labplot.png
+    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/48-application-x-labplot.png
+    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/64-application-x-labplot.png
+    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/128-application-x-labplot.png
+    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/256-application-x-labplot.png
+    ${CMAKE_CURRENT_SOURCE_DIR}/../icons/512-application-x-labplot.png
 )
 
 add_subdirectory(3rdparty)
@@ -762,33 +762,33 @@ if(APPLE AND ${ECM_VERSION} VERSION_GREATER "5.48.0")
     ecm_add_app_icon(LABPLOT_SOURCE ICONS ${LML_ICONS} OUTFILE_BASENAME LML_ICONS)
 endif()
 
-add_executable(labplot2 ${LABPLOT_SOURCE} ${GUI_QRC} ${qml_QRC})
-target_link_libraries(labplot2 labplot2lib labplot2backendlib labplot2nsllib )
+add_executable(labplot ${LABPLOT_SOURCE} ${GUI_QRC} ${qml_QRC})
+target_link_libraries(labplot labplotlib labplotbackendlib labplotnsllib)
 
 #if(KUserFeedbackQt6_FOUND)
-#    target_link_libraries(labplot2 KUserFeedbackCoreQt6 KUserFeedbackWidgetsQt6 )
+#    target_link_libraries(labplot KUserFeedbackCoreQt6 KUserFeedbackWidgetsQt6)
 #endif()
-target_compile_definitions(labplot2 PRIVATE ${LABPLOT_COMPILE_DEFINITIONS})
+target_compile_definitions(labplot PRIVATE ${LABPLOT_COMPILE_DEFINITIONS})
 
 if(APPLE) # Apple app package
-    set_target_properties(labplot2 PROPERTIES MACOSX_BUNDLE_INFO_PLIST ${CMAKE_CURRENT_SOURCE_DIR}/Info.plist)
-    set_target_properties(labplot2 PROPERTIES
-    MACOSX_BUNDLE_BUNDLE_NAME "LabPlot2"
-    MACOSX_BUNDLE_LONG_VERSION_STRING "${labplot2_VERSION}"
-    MACOSX_BUNDLE_SHORT_VERSION_STRING "${labplot2_VERSION}"
+    set_target_properties(labplot PROPERTIES MACOSX_BUNDLE_INFO_PLIST ${CMAKE_CURRENT_SOURCE_DIR}/Info.plist)
+    set_target_properties(labplot PROPERTIES
+    MACOSX_BUNDLE_BUNDLE_NAME "LabPlot"
+    MACOSX_BUNDLE_LONG_VERSION_STRING "${labplot_VERSION}"
+    MACOSX_BUNDLE_SHORT_VERSION_STRING "${labplot_VERSION}"
     MACOSX_BUNDLE_GUI_IDENTIFIER "org.kde.labplot")
 endif()
 
 ############## installation ################################
-install(TARGETS labplot2 ${KDE_INSTALL_TARGETS_DEFAULT_ARGS})
-install(FILES ${KDEFRONTEND_DIR}/splash.png ${KDEFRONTEND_DIR}/labplot2.ico ${CMAKE_CURRENT_SOURCE_DIR}/../icons/application-x-labplot2.ico DESTINATION ${KDE_INSTALL_DATADIR}/${PROJECT_NAME} )
-install(FILES org.kde.labplot2.desktop DESTINATION ${KDE_INSTALL_APPDIR} )
-install(FILES labplot2.xml DESTINATION ${KDE_INSTALL_MIMEDIR} )
+install(TARGETS labplot ${KDE_INSTALL_TARGETS_DEFAULT_ARGS})
+install(FILES ${KDEFRONTEND_DIR}/splash.png ${KDEFRONTEND_DIR}/labplot.ico ${CMAKE_CURRENT_SOURCE_DIR}/../icons/application-x-labplot.ico DESTINATION ${KDE_INSTALL_DATADIR}/${PROJECT_NAME})
+install(FILES org.kde.labplot.desktop DESTINATION ${KDE_INSTALL_APPDIR})
+install(FILES labplot.xml DESTINATION ${KDE_INSTALL_MIMEDIR})
 # if(${ECM_VERSION} VERSION_GREATER "5.58.0")
-#     install(FILES labplot2_themes.knsrc DESTINATION ${KDE_INSTALL_KNSRCDIR} )
-#     install(FILES labplot2_datasets.knsrc DESTINATION ${KDE_INSTALL_KNSRCDIR} )
+#     install(FILES labplot2_themes.knsrc DESTINATION ${KDE_INSTALL_KNSRCDIR})
+#     install(FILES labplot2_datasets.knsrc DESTINATION ${KDE_INSTALL_KNSRCDIR})
 # else ()
-#     install(FILES labplot2_themes.knsrc DESTINATION ${KDE_INSTALL_CONFDIR} )
-#     install(FILES labplot2_datasets.knsrc DESTINATION ${KDE_INSTALL_CONFDIR} )
+#     install(FILES labplot2_themes.knsrc DESTINATION ${KDE_INSTALL_CONFDIR})
+#     install(FILES labplot2_datasets.knsrc DESTINATION ${KDE_INSTALL_CONFDIR})
 # endif()
-update_xdg_mimetypes(${KDE_INSTALL_MIMEDIR} )
+update_xdg_mimetypes(${KDE_INSTALL_MIMEDIR})
diff --git a/src/Info.plist b/src/Info.plist
index a543553339..28b1a38bc7 100644
--- a/src/Info.plist
+++ b/src/Info.plist
@@ -5,7 +5,7 @@
 	<key>CFBundleDevelopmentRegion</key>
 	<string>English</string>
 	<key>CFBundleExecutable</key>
-	<string>labplot2</string>
+	<string>labplot</string>
 	<key>CFBundleGetInfoString</key>
 	<string>${MACOSX_BUNDLE_INFO_STRING}</string>
 	<key>CFBundleIconFile</key>
@@ -38,7 +38,7 @@
 	<array>
 		<dict>
 			<key>CFBundleTypeName</key>
-			<string>LabPlot2 project</string>
+			<string>LabPlot project</string>
 			<key>CFBundleTypeIconFile</key>
 			<string>LML_ICONS.icns</string>
 			<key>CFBundleTypeExtensions</key>
@@ -47,7 +47,7 @@
 			</array>
 			<key>CFBundleTypeMIMETypes</key>
 			<array>
-				<string>application/x-labplot2</string>
+				<string>application/x-labplot</string>
 			</array>
 			<key>CFBundleTypeRole</key>
 			<string>Viewer</string>
diff --git a/src/XmlMessages.sh b/src/XmlMessages.sh
index 5dc1e8497f..ccb862580c 100755
--- a/src/XmlMessages.sh
+++ b/src/XmlMessages.sh
@@ -1,13 +1,13 @@
 function get_files
 {
-    echo labplot2.xml
+    echo labplot.xml
 }
 
 function po_for_file
 {
     case "$1" in
-       labplot2.xml)
-           echo labplot2_xml_mimetypes.po
+       labplot.xml)
+           echo labplot_xml_mimetypes.po
        ;;
     esac
 }
@@ -15,7 +15,7 @@ function po_for_file
 function tags_for_file
 {
     case "$1" in
-       labplot2.xml)
+       labplot.xml)
            echo comment
        ;;
     esac
diff --git a/src/backend/cantorWorksheet/CantorWorksheet.cpp b/src/backend/cantorWorksheet/CantorWorksheet.cpp
index f12c46b3e1..26aa8a78b2 100644
--- a/src/backend/cantorWorksheet/CantorWorksheet.cpp
+++ b/src/backend/cantorWorksheet/CantorWorksheet.cpp
@@ -352,6 +352,9 @@ void CantorWorksheet::fillColumnContextMenu(QMenu* menu, Column* column) {
 #ifndef SDK
 	if (m_view)
 		m_view->fillColumnContextMenu(menu, column);
+#else
+	Q_UNUSED(menu)
+	Q_UNUSED(column)
 #endif
 }
 
diff --git a/src/kdefrontend/LabPlot.cpp b/src/kdefrontend/LabPlot.cpp
index 58b77543bf..e6a3bf5602 100644
--- a/src/kdefrontend/LabPlot.cpp
+++ b/src/kdefrontend/LabPlot.cpp
@@ -83,14 +83,14 @@ int main(int argc, char* argv[]) {
 	QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
 #endif
 	QApplication app(argc, argv);
-	KLocalizedString::setApplicationDomain("labplot2");
+	KLocalizedString::setApplicationDomain("labplot");
 	KCrash::initialize();
 
 	MainWin::updateLocale();
 
 	QString systemInfo{getSystemInfo()};
 
-	KAboutData aboutData(QStringLiteral("labplot2"),
+	KAboutData aboutData(QStringLiteral("labplot"),
 						 QStringLiteral("LabPlot"),
 						 QLatin1String(LVERSION),
 						 i18n("LabPlot is a FREE, open-source and cross-platform Data Visualization and Analysis software accessible to everyone."),
@@ -112,7 +112,7 @@ int main(int argc, char* argv[]) {
 						QStringLiteral("[email protected]"),
 						QString());
 	aboutData.addCredit(i18n("Garvit Khatri"),
-						i18nc("@info:credit", "Porting LabPlot2 to KF5 and Integration with Cantor"),
+						i18nc("@info:credit", "Porting LabPlot to KF5 and Integration with Cantor"),
 						QStringLiteral("[email protected]"),
 						QString());
 	aboutData.addCredit(i18n("Christoph Roick"),
@@ -120,7 +120,7 @@ int main(int argc, char* argv[]) {
 						QStringLiteral("[email protected]"),
 						QString());
 	aboutData.setOrganizationDomain(QByteArray("kde.org"));
-	aboutData.setDesktopFileName(QStringLiteral("org.kde.labplot2"));
+	aboutData.setDesktopFileName(QStringLiteral("org.kde.labplot"));
 	KAboutData::setApplicationData(aboutData);
 
 	const auto& group = Settings::settingsGeneral();
diff --git a/src/kdefrontend/MainWin.cpp b/src/kdefrontend/MainWin.cpp
index fd0a366150..27d2cd37d0 100644
--- a/src/kdefrontend/MainWin.cpp
+++ b/src/kdefrontend/MainWin.cpp
@@ -304,7 +304,7 @@ void MainWin::initGUI(const QString& fileName) {
 	m_hamburgerMenu->setMenuBar(menuBar());
 #endif
 
-	setWindowIcon(QIcon::fromTheme(QLatin1String("LabPlot2"), QGuiApplication::windowIcon()));
+	setWindowIcon(QIcon::fromTheme(QLatin1String("LabPlot"), QGuiApplication::windowIcon()));
 	setAttribute(Qt::WA_DeleteOnClose);
 
 	// make the status bar of a fixed size in order to avoid height changes when placing a ProgressBar there.
diff --git a/src/kdefrontend/PlotTemplateDialog.cpp b/src/kdefrontend/PlotTemplateDialog.cpp
index 62dd2a4978..9b61d72976 100644
--- a/src/kdefrontend/PlotTemplateDialog.cpp
+++ b/src/kdefrontend/PlotTemplateDialog.cpp
@@ -121,9 +121,9 @@ void PlotTemplateDialog::customTemplatePathChanged(const QString& path) {
 
 QString PlotTemplateDialog::defaultTemplateInstallPath() {
 	// folder where config files will be stored in object specific sub-folders:
-	// Linux    - ~/.local/share/labplot2/plot_templates/
-	// Mac      - /Library/Application Support/labplot2
-	// Windows  - C:/Users/<USER>/AppData/Roaming/labplot2/plot_templates/
+	// Linux    - ~/.local/share/labplot/plot_templates/
+	// Mac      - /Library/Application Support/labplot
+	// Windows  - C:/Users/<USER>/AppData/Roaming/labplot/plot_templates/
 	return QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1String("/plot_templates/");
 }
 
diff --git a/src/kdefrontend/TemplateHandler.cpp b/src/kdefrontend/TemplateHandler.cpp
index 7acb9a916e..497e1c8f51 100644
--- a/src/kdefrontend/TemplateHandler.cpp
+++ b/src/kdefrontend/TemplateHandler.cpp
@@ -109,9 +109,9 @@ TemplateHandler::TemplateHandler(QWidget* parent, const QString& className, bool
 	m_className = className.toLower();
 
 	// folder where config files will be stored in object specific sub-folders:
-	// Linux    - ~/.local/share/labplot2/templates/
+	// Linux    - ~/.local/share/labplot/templates/
 	// Mac      - //TODO
-	// Windows  - C:/Users/<USER>/AppData/Roaming/labplot2/templates/
+	// Windows  - C:/Users/<USER>/AppData/Roaming/labplot/templates/
 	m_dirName = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1String("/templates/");
 
 	this->retranslateUi();
diff --git a/src/kdefrontend/labplot2.ico b/src/kdefrontend/labplot.ico
similarity index 100%
rename from src/kdefrontend/labplot2.ico
rename to src/kdefrontend/labplot.ico
diff --git a/src/kdefrontend/labplot.qrc b/src/kdefrontend/labplot.qrc
new file mode 100644
index 0000000000..53cc6bcde7
--- /dev/null
+++ b/src/kdefrontend/labplot.qrc
@@ -0,0 +1,6 @@
+<!DOCTYPE RCC>
+<RCC version="1.0">
+    <qresource prefix="/kxmlgui5/labplot">
+        <file>labplotui.rc</file>
+    </qresource>
+</RCC>
diff --git a/src/kdefrontend/labplot2.qrc b/src/kdefrontend/labplot2.qrc
deleted file mode 100644
index c75dad2058..0000000000
--- a/src/kdefrontend/labplot2.qrc
+++ /dev/null
@@ -1,6 +0,0 @@
-<!DOCTYPE RCC>
-<RCC version="1.0">
-    <qresource prefix="/kxmlgui5/labplot2">
-        <file>labplot2ui.rc</file>
-    </qresource>
-</RCC>
diff --git a/src/kdefrontend/labplot2ui.rc b/src/kdefrontend/labplotui.rc
similarity index 100%
rename from src/kdefrontend/labplot2ui.rc
rename to src/kdefrontend/labplotui.rc
diff --git a/src/kdefrontend/welcomescreen/HelpList.qml b/src/kdefrontend/welcomescreen/HelpList.qml
index 2d1e081d39..74290add76 100644
--- a/src/kdefrontend/welcomescreen/HelpList.qml
+++ b/src/kdefrontend/welcomescreen/HelpList.qml
@@ -13,12 +13,12 @@ ListView {
                 model: ListModel {
                     ListElement {
                         name: "Documentation"
-                        link: "https://docs.kde.org/?application=labplot2"
+                        link: "https://docs.kde.org/?application=labplot"
                     }
 
                     ListElement {
                         name: "FAQ"
-                        link: "https://docs.kde.org/?application=labplot2&branch=trunk5&path=faq.html"
+                        link: "https://docs.kde.org/?application=labplot&branch=trunk5&path=faq.html"
                     }
 
                     ListElement {
diff --git a/src/labplot.xml b/src/labplot.xml
new file mode 100644
index 0000000000..917ece4b01
--- /dev/null
+++ b/src/labplot.xml
@@ -0,0 +1,36 @@
+<?xml version="1.0" encoding="utf-8"?>
+<mime-info xmlns="http://www.freedesktop.org/standards/shared-mime-info">
+  <mime-type type="application/x-labplot2">
+    <sub-class-of type="application/gzip"/>
+    <comment>LabPlot Project File</comment>
+    <comment xml:lang="ar">ملف مشروع معمل رسم</comment>
+    <comment xml:lang="ca">Fitxer de projecte LabPlot</comment>
+    <comment xml:lang="ca@valencia">Fitxer de projecte LabPlot</comment>
+    <comment xml:lang="cs">Soubor projektu LabPlot</comment>
+    <comment xml:lang="de">LabPlot-Projektdatei</comment>
+    <comment xml:lang="en_GB">LabPlot Project File</comment>
+    <comment xml:lang="eo">LabPlot-projekta dosiero</comment>
+    <comment xml:lang="es">Archivo de proyecto de LabPlot</comment>
+    <comment xml:lang="eu">LabPlot-ko proiektu-fitxategia</comment>
+    <comment xml:lang="fi">LabPlot-projektitiedosto</comment>
+    <comment xml:lang="fr">Fichier de projet pour « LabPlot »</comment>
+    <comment xml:lang="gl">Ficheiro de proxecto de LabPlot.</comment>
+    <comment xml:lang="ia">File de Projecto de LabPlot</comment>
+    <comment xml:lang="it">File di progetto LabPlot</comment>
+    <comment xml:lang="ka">LabPlot-ის პროექტის ფაილი</comment>
+    <comment xml:lang="ko">LabPlot 프로젝트 파일</comment>
+    <comment xml:lang="lt">LabPlot projekto failas</comment>
+    <comment xml:lang="nl">Projectbestand LabPlot</comment>
+    <comment xml:lang="nn">LabPlot-prosjektfil</comment>
+    <comment xml:lang="pl">Plik projektu LabPlot</comment>
+    <comment xml:lang="pt">Ficheiro de Projecto do LabPlot</comment>
+    <comment xml:lang="pt_BR">Arquivo de projeto do LabPlot</comment>
+    <comment xml:lang="ru">Файл проекта LabPlot</comment>
+    <comment xml:lang="sl">Projektna datoteka LabPlot</comment>
+    <comment xml:lang="sv">Labplot projektfil</comment>
+    <comment xml:lang="tr">LabPlot Proje Dosyası</comment>
+    <comment xml:lang="uk">файл проєкту LabPlot</comment>
+    <comment xml:lang="zh_CN">LabPlot 工程文件</comment>
+    <glob pattern="*.lml"/>
+  </mime-type>
+</mime-info>
diff --git a/src/labplot2.xml b/src/labplot2.xml
deleted file mode 100644
index 483ff2d6b1..0000000000
--- a/src/labplot2.xml
+++ /dev/null
@@ -1,36 +0,0 @@
-<?xml version="1.0" encoding="utf-8"?>
-<mime-info xmlns="http://www.freedesktop.org/standards/shared-mime-info">
-  <mime-type type="application/x-labplot2">
-    <sub-class-of type="application/gzip"/>
-    <comment>LabPlot2 Project File</comment>
-    <comment xml:lang="ar">ملف مشروع معمل رسم2</comment>
-    <comment xml:lang="ca">Fitxer de projecte LabPlot2</comment>
-    <comment xml:lang="ca@valencia">Fitxer de projecte LabPlot2</comment>
-    <comment xml:lang="cs">Soubor projektu LabPlot2</comment>
-    <comment xml:lang="de">LabPlot2-Projektdatei</comment>
-    <comment xml:lang="en_GB">LabPlot2 Project File</comment>
-    <comment xml:lang="eo">LabPlot2-projekta dosiero</comment>
-    <comment xml:lang="es">Archivo de proyecto de LabPlot2</comment>
-    <comment xml:lang="eu">LabPlot2-ko proiektu-fitxategia</comment>
-    <comment xml:lang="fi">LabPlot2-projektitiedosto</comment>
-    <comment xml:lang="fr">Fichier de projet pour « LabPlot2 »</comment>
-    <comment xml:lang="gl">Ficheiro de proxecto de LabPlot2.</comment>
-    <comment xml:lang="ia">File de Projecto de LabPlot2</comment>
-    <comment xml:lang="it">File di progetto LabPlot2</comment>
-    <comment xml:lang="ka">LabPlot2-ის პროექტის ფაილი</comment>
-    <comment xml:lang="ko">LabPlot2 프로젝트 파일</comment>
-    <comment xml:lang="lt">LabPlot2 projekto failas</comment>
-    <comment xml:lang="nl">Projectbestand LabPlot</comment>
-    <comment xml:lang="nn">LabPlot2-prosjektfil</comment>
-    <comment xml:lang="pl">Plik projektu LabPlot2</comment>
-    <comment xml:lang="pt">Ficheiro de Projecto do LabPlot2</comment>
-    <comment xml:lang="pt_BR">Arquivo de projeto do LabPlot2</comment>
-    <comment xml:lang="ru">Файл проекта LabPlot2</comment>
-    <comment xml:lang="sl">Projektna datoteka LabPlot2</comment>
-    <comment xml:lang="sv">Labplot2 projektfil</comment>
-    <comment xml:lang="tr">LabPlot2 Proje Dosyası</comment>
-    <comment xml:lang="uk">файл проєкту LabPlot2</comment>
-    <comment xml:lang="zh_CN">LabPlot2 工程文件</comment>
-    <glob pattern="*.lml"/>
-  </mime-type>
-</mime-info>
diff --git a/src/org.kde.labplot2.desktop b/src/org.kde.labplot.desktop
similarity index 88%
rename from src/org.kde.labplot2.desktop
rename to src/org.kde.labplot.desktop
index e995f1240a..8a2332885b 100755
--- a/src/org.kde.labplot2.desktop
+++ b/src/org.kde.labplot.desktop
@@ -1,44 +1,44 @@
 [Desktop Entry]
 Type=Application
-Exec=labplot2 %f
-Icon=labplot2
-Name=LabPlot2
-Name[ar]=معمل الرسم2
-Name[bs]=LabPlot2
-Name[ca]=LabPlot2
-Name[ca@valencia]=LabPlot2
-Name[cs]=LabPlot2
-Name[da]=LabPlot2
-Name[de]=LabPlot2
-Name[el]=LabPlot2
-Name[en_GB]=LabPlot2
-Name[eo]=LabPlot2
-Name[es]=LabPlot2
-Name[et]=LabPlot2
-Name[eu]=LabPlot2
-Name[fi]=LabPlot2
-Name[fr]=LabPlot2
-Name[gl]=LabPlot2
-Name[hu]=LabPlot2
-Name[ia]=LabPlot2
-Name[id]=LabPlot2
-Name[it]=LabPlot2
-Name[ka]=LabPlot2
-Name[ko]=LabPlot2
-Name[nl]=LabPlot2
-Name[nn]=LabPlot2
-Name[pl]=LabPlot2
-Name[pt]=LabPlot2
-Name[pt_BR]=LabPlot2
-Name[ru]=LabPlot2
-Name[sk]=LabPlot2
-Name[sl]=LabPlot2
-Name[sv]=Labplot 2
-Name[tr]=LabPlot2
-Name[uk]=LabPlot2
-Name[x-test]=xxLabPlot2xx
-Name[zh_CN]=LabPlot2
-Name[zh_TW]=LabPlot2
+Exec=labplot %f
+Icon=labplot
+Name=LabPlot
+Name[ar]=معمل الرسم
+Name[bs]=LabPlot
+Name[ca]=LabPlot
+Name[ca@valencia]=LabPlot
+Name[cs]=LabPlot
+Name[da]=LabPlot
+Name[de]=LabPlot
+Name[el]=LabPlot
+Name[en_GB]=LabPlot
+Name[eo]=LabPlot
+Name[es]=LabPlot
+Name[et]=LabPlot
+Name[eu]=LabPlot
+Name[fi]=LabPlot
+Name[fr]=LabPlot
+Name[gl]=LabPlot
+Name[hu]=LabPlot
+Name[ia]=LabPlot
+Name[id]=LabPlot
+Name[it]=LabPlot
+Name[ka]=LabPlot
+Name[ko]=LabPlot
+Name[nl]=LabPlot
+Name[nn]=LabPlot
+Name[pl]=LabPlot
+Name[pt]=LabPlot
+Name[pt_BR]=LabPlot
+Name[ru]=LabPlot
+Name[sk]=LabPlot
+Name[sl]=LabPlot
+Name[sv]=Labplot
+Name[tr]=LabPlot
+Name[uk]=LabPlot
+Name[x-test]=xxLabPlotxx
+Name[zh_CN]=LabPlot
+Name[zh_TW]=LabPlot
 GenericName=Data Visualization and Analysis software
 GenericName[ar]=برنامج تصور وتحليل البيانات
 GenericName[ca]=Programari de visualització i anàlisi de dades
@@ -93,6 +93,6 @@ Comment[tr]=LabPlot; herkese açık ÜCRETSİZ, açık kaynaklı ve çapraz plat
 Comment[uk]=LabPlot є вільним, доступним для будь-кого програмним забезпеченням з відкритим кодом, яке працює на багатьох платформах і виконує візуалізацію та аналіз даних.
 Comment[x-test]=xxLabPlot is a FREE, open source and cross-platform Data Visualization and Analysis software accessible to everyone.xx
 Terminal=false
-MimeType=application/x-LabPlot-gzip;application/x-LabPlot-xz;application/x-labplot2;
+MimeType=application/x-LabPlot-gzip;application/x-LabPlot-xz;application/x-labplot;
 Categories=Qt;KDE;Education;Science;Physics;Math;
-X-DocPath=labplot2/index.html
+X-DocPath=labplot/index.html
diff --git a/tests/CMakeLists.txt b/tests/CMakeLists.txt
index acc5b979f0..10c6eea6b0 100644
--- a/tests/CMakeLists.txt
+++ b/tests/CMakeLists.txt
@@ -1,16 +1,16 @@
-set(SRC_DIR ${labplot2_SOURCE_DIR}/src)
+set(SRC_DIR ${labplot_SOURCE_DIR}/src)
 include_directories(${SRC_DIR} ${GSL_INCLUDE_DIR})
 
 # shared code
-add_library(labplot2test STATIC CommonTest.cpp analysis/AnalysisTest.cpp nsl/NSLTest.h ../src/backend/lib/Debug.cpp)
-target_link_libraries(labplot2test labplot2nsllib Qt${QT_MAJOR_VERSION}::Test KF${KF_MAJOR_VERSION}::ConfigCore Qt${QT_MAJOR_VERSION}::Widgets KF${KF_MAJOR_VERSION}::I18n)
-add_library(labplot2metatest STATIC CommonMetaTest.cpp)
-target_link_libraries(labplot2metatest labplot2backendlib labplot2lib labplot2test)
+add_library(labplottest STATIC CommonTest.cpp analysis/AnalysisTest.cpp nsl/NSLTest.h ../src/backend/lib/Debug.cpp)
+target_link_libraries(labplottest labplotnsllib Qt${QT_MAJOR_VERSION}::Test KF${KF_MAJOR_VERSION}::ConfigCore Qt${QT_MAJOR_VERSION}::Widgets KF${KF_MAJOR_VERSION}::I18n)
+add_library(labplotmetatest STATIC CommonMetaTest.cpp)
+target_link_libraries(labplotmetatest labplotbackendlib labplotlib labplottest)
 
 if(KUserFeedback_FOUND AND QT_MAJOR_VERSION EQUAL 6)
-    target_link_libraries(labplot2test KUserFeedbackCoreQt6 KUserFeedbackWidgetsQt6)
+    target_link_libraries(labplottest KUserFeedbackCoreQt6 KUserFeedbackWidgetsQt6)
 endif()
-target_compile_definitions(labplot2test PUBLIC ${LABPLOT_COMPILE_DEFINITIONS})
+target_compile_definitions(labplottest PUBLIC ${LABPLOT_COMPILE_DEFINITIONS})
 
 add_subdirectory(analysis)
 add_subdirectory(backend)
@@ -30,6 +30,6 @@ endif()
 option(ENABLE_TEST_DEPENDENCIES "Enable Dependencies Tests" ON)
 if(ENABLE_TEST_DEPENDENCIES)
     add_executable (DependenciesTest DependenciesTest.cpp)
-    target_link_libraries(DependenciesTest labplot2test labplot2lib)
+    target_link_libraries(DependenciesTest labplottest labplotlib)
     add_test(NAME DependenciesTest COMMAND DependenciesTest)
 endif()
diff --git a/tests/CommonTest.cpp b/tests/CommonTest.cpp
index d32c766b12..751e076555 100644
--- a/tests/CommonTest.cpp
+++ b/tests/CommonTest.cpp
@@ -20,7 +20,7 @@
 void CommonTest::initTestCase() {
 	// always enable debugging
 	enableDebugTrace(true);
-	KLocalizedString::setApplicationDomain("labplot2");
+	KLocalizedString::setApplicationDomain("labplot");
 
 #ifdef _WIN32
 //	if (AttachConsole(ATTACH_PARENT_PROCESS)) {
diff --git a/tests/analysis/convolution/CMakeLists.txt b/tests/analysis/convolution/CMakeLists.txt
index e06fc52591..eec7219f09 100644
--- a/tests/analysis/convolution/CMakeLists.txt
+++ b/tests/analysis/convolution/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(ConvolutionTest ConvolutionTest.cpp)
 
-target_link_libraries(ConvolutionTest labplot2backendlib labplot2lib labplot2test)
+target_link_libraries(ConvolutionTest labplotbackendlib labplotlib labplottest)
 
 add_test(NAME ConvolutionTest COMMAND ConvolutionTest)
diff --git a/tests/analysis/correlation/CMakeLists.txt b/tests/analysis/correlation/CMakeLists.txt
index 46843660ca..2779faaa35 100644
--- a/tests/analysis/correlation/CMakeLists.txt
+++ b/tests/analysis/correlation/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(CorrelationTest CorrelationTest.cpp)
 
-target_link_libraries(CorrelationTest labplot2backendlib labplot2lib labplot2test)
+target_link_libraries(CorrelationTest labplotbackendlib labplotlib labplottest)
 
 add_test(NAME CorrelationTest COMMAND CorrelationTest)
diff --git a/tests/analysis/differentiation/CMakeLists.txt b/tests/analysis/differentiation/CMakeLists.txt
index 2562bb8235..6437d2ecf8 100644
--- a/tests/analysis/differentiation/CMakeLists.txt
+++ b/tests/analysis/differentiation/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(DifferentiationTest DifferentiationTest.cpp)
 
-target_link_libraries(DifferentiationTest labplot2backendlib labplot2lib labplot2test)
+target_link_libraries(DifferentiationTest labplotbackendlib labplotlib labplottest)
 
 add_test(NAME DifferentiationTest COMMAND DifferentiationTest)
diff --git a/tests/analysis/fit/CMakeLists.txt b/tests/analysis/fit/CMakeLists.txt
index 212271d73c..ed68353f68 100644
--- a/tests/analysis/fit/CMakeLists.txt
+++ b/tests/analysis/fit/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(FitTest FitTest.cpp)
 
-target_link_libraries(FitTest labplot2backendlib labplot2lib labplot2test)
+target_link_libraries(FitTest labplotbackendlib labplotlib labplottest)
 
 add_test(NAME FitTest COMMAND FitTest)
diff --git a/tests/analysis/fourier/CMakeLists.txt b/tests/analysis/fourier/CMakeLists.txt
index b3d78d103d..e6ae086527 100644
--- a/tests/analysis/fourier/CMakeLists.txt
+++ b/tests/analysis/fourier/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(FourierTest FourierTest.cpp)
 
-target_link_libraries(FourierTest labplot2backendlib labplot2lib labplot2test)
+target_link_libraries(FourierTest labplotbackendlib labplotlib labplottest)
 
 add_test(NAME FourierTest COMMAND FourierTest)
diff --git a/tests/analysis/hilberttransform/CMakeLists.txt b/tests/analysis/hilberttransform/CMakeLists.txt
index 1819a7eb88..5927850f3d 100644
--- a/tests/analysis/hilberttransform/CMakeLists.txt
+++ b/tests/analysis/hilberttransform/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(HilbertTransformTest HilbertTransformTest.cpp)
 
-target_link_libraries(HilbertTransformTest labplot2backendlib labplot2lib labplot2test)
+target_link_libraries(HilbertTransformTest labplotbackendlib labplotlib labplottest)
 
 add_test(NAME HilbertTransformTest COMMAND HilbertTransformTest)
diff --git a/tests/analysis/integration/CMakeLists.txt b/tests/analysis/integration/CMakeLists.txt
index 89b977ba26..7596cfdc69 100644
--- a/tests/analysis/integration/CMakeLists.txt
+++ b/tests/analysis/integration/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(IntegrationTest IntegrationTest.cpp)
 
-target_link_libraries(IntegrationTest labplot2backendlib labplot2lib labplot2test)
+target_link_libraries(IntegrationTest labplotbackendlib labplotlib labplottest)
 
 add_test(NAME IntegrationTest COMMAND IntegrationTest)
diff --git a/tests/analysis/interpolation/CMakeLists.txt b/tests/analysis/interpolation/CMakeLists.txt
index 82d45450c5..817487a2cf 100644
--- a/tests/analysis/interpolation/CMakeLists.txt
+++ b/tests/analysis/interpolation/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(InterpolationTest InterpolationTest.cpp)
 
-target_link_libraries(InterpolationTest labplot2backendlib labplot2lib labplot2test)
+target_link_libraries(InterpolationTest labplotbackendlib labplotlib labplottest)
 
 add_test(NAME InterpolationTest COMMAND InterpolationTest)
diff --git a/tests/analysis/smooth/CMakeLists.txt b/tests/analysis/smooth/CMakeLists.txt
index 39246c7419..74b250fb74 100644
--- a/tests/analysis/smooth/CMakeLists.txt
+++ b/tests/analysis/smooth/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(SmoothTest SmoothTest.cpp)
 
-target_link_libraries(SmoothTest labplot2backendlib labplot2lib labplot2test)
+target_link_libraries(SmoothTest labplotbackendlib labplotlib labplottest)
 
 add_test(NAME SmoothTest COMMAND SmoothTest)
diff --git a/tests/backend/Axis/CMakeLists.txt b/tests/backend/Axis/CMakeLists.txt
index fe633b2e00..576a97350f 100644
--- a/tests/backend/Axis/CMakeLists.txt
+++ b/tests/backend/Axis/CMakeLists.txt
@@ -2,14 +2,14 @@ option(ENABLE_TEST_BACKEND_AXIS "Enable Axis Tests" ON)
 
 if(ENABLE_TEST_BACKEND_AXIS)
     add_executable(AxisTest AxisTest.cpp)
-    target_link_libraries(AxisTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(AxisTest labplotbackendlib labplotlib labplottest)
     add_test(NAME AxisTest COMMAND AxisTest)
 
     add_executable(AxisTest2 AxisTest2.cpp)
-    target_link_libraries(AxisTest2 labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(AxisTest2 labplotbackendlib labplotlib labplottest)
     add_test(NAME AxisTest2 COMMAND AxisTest2)
 
     add_executable(AxisTest3 AxisTest3.cpp)
-    target_link_libraries(AxisTest3 labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(AxisTest3 labplotbackendlib labplotlib labplottest)
     add_test(NAME AxisTest3 COMMAND AxisTest3)
 endif()
diff --git a/tests/backend/BarPlot/CMakeLists.txt b/tests/backend/BarPlot/CMakeLists.txt
index f7ab866131..2d1af359d8 100644
--- a/tests/backend/BarPlot/CMakeLists.txt
+++ b/tests/backend/BarPlot/CMakeLists.txt
@@ -3,7 +3,7 @@ option(ENABLE_TEST_BACKEND_BARPLOT "Enable Barplot Tests" ON)
 if(ENABLE_TEST_BACKEND_BARPLOT)
     add_executable (BarPlotTest BarPlotTest.cpp)
 
-    target_link_libraries(BarPlotTest labplot2backendlib labplot2test labplot2lib)
+    target_link_libraries(BarPlotTest labplotbackendlib labplottest labplotlib)
 
     add_test(NAME BarPlotTest COMMAND BarPlotTest)
 endif()
diff --git a/tests/backend/Column/CMakeLists.txt b/tests/backend/Column/CMakeLists.txt
index 13ae4d47b9..a89c5a9b4e 100644
--- a/tests/backend/Column/CMakeLists.txt
+++ b/tests/backend/Column/CMakeLists.txt
@@ -3,7 +3,7 @@ option(ENABLE_TEST_BACKEND_COLUMN "Enable Column Tests" ON)
 if(ENABLE_TEST_BACKEND_COLUMN)
 	add_executable (ColumnTest ColumnTest.cpp)
 
-	target_link_libraries(ColumnTest labplot2metatest)
+	target_link_libraries(ColumnTest labplotmetatest)
 
 	add_test(NAME ColumnTest COMMAND ColumnTest)
 endif()
diff --git a/tests/backend/Datapicker/CMakeLists.txt b/tests/backend/Datapicker/CMakeLists.txt
index 822b28eda5..bf39d9b41e 100644
--- a/tests/backend/Datapicker/CMakeLists.txt
+++ b/tests/backend/Datapicker/CMakeLists.txt
@@ -3,7 +3,7 @@ option(ENABLE_TEST_BACKEND_DATAPICKER "Enable Datapicker Tests" ON)
 if(ENABLE_TEST_BACKEND_DATAPICKER)
     add_executable (DatapickerTest DatapickerTest.cpp)
 
-    target_link_libraries(DatapickerTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(DatapickerTest labplotbackendlib labplotlib labplottest)
 
     add_test(NAME DatapickerTest COMMAND DatapickerTest)
 endif()
diff --git a/tests/backend/InfoElement/CMakeLists.txt b/tests/backend/InfoElement/CMakeLists.txt
index 9d2f8dbb62..f72ffe0808 100644
--- a/tests/backend/InfoElement/CMakeLists.txt
+++ b/tests/backend/InfoElement/CMakeLists.txt
@@ -3,7 +3,7 @@ option(ENABLE_TEST_BACKEND_INFOELEMENT "Enable InfoElement Tests" ON)
 if(ENABLE_TEST_BACKEND_INFOELEMENT)
     add_executable (InfoElementTest InfoElementTest.cpp)
 
-    target_link_libraries(InfoElementTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(InfoElementTest labplotbackendlib labplotlib labplottest)
 
     add_test(NAME InfoElementTest COMMAND InfoElementTest)
 endif()
diff --git a/tests/backend/Parser/CMakeLists.txt b/tests/backend/Parser/CMakeLists.txt
index 0a93d9bd10..3fc6071e57 100644
--- a/tests/backend/Parser/CMakeLists.txt
+++ b/tests/backend/Parser/CMakeLists.txt
@@ -3,7 +3,7 @@ option(ENABLE_TEST_BACKEND_PARSER "Enable Parser Tests" ON)
 if(ENABLE_TEST_BACKEND_PARSER)
     add_executable (ParserTest ParserTest.cpp)
 
-    target_link_libraries(ParserTest labplot2test labplot2backendlib)
+    target_link_libraries(ParserTest labplottest labplotbackendlib)
 
     add_test(NAME ParserTest COMMAND ParserTest)
 endif()
diff --git a/tests/backend/Range/CMakeLists.txt b/tests/backend/Range/CMakeLists.txt
index d4b75794fa..34468d8183 100644
--- a/tests/backend/Range/CMakeLists.txt
+++ b/tests/backend/Range/CMakeLists.txt
@@ -3,7 +3,7 @@ option(ENABLE_TEST_BACKEND_RANGE "Enable Range Tests" ON)
 if(ENABLE_TEST_BACKEND_RANGE)
     add_executable (RangeTest RangeTest.cpp)
 
-    target_link_libraries(RangeTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(RangeTest labplotbackendlib labplotlib labplottest)
 
     add_test(NAME RangeTest COMMAND RangeTest)
 endif()
diff --git a/tests/backend/Retransform/CMakeLists.txt b/tests/backend/Retransform/CMakeLists.txt
index cbec49f3c5..38a5394fa8 100644
--- a/tests/backend/Retransform/CMakeLists.txt
+++ b/tests/backend/Retransform/CMakeLists.txt
@@ -3,7 +3,7 @@ option(ENABLE_TEST_BACKEND_RETRANSFORM "Enable Retransform Tests" ON)
 if(ENABLE_TEST_BACKEND_RETRANSFORM)
     add_executable (RetransformTest RetransformTest.cpp)
 
-    target_link_libraries(RetransformTest labplot2metatest)
+    target_link_libraries(RetransformTest labplotmetatest)
 
     add_test(NAME RetransformTest COMMAND RetransformTest)
 endif()
diff --git a/tests/backend/TextLabel/CMakeLists.txt b/tests/backend/TextLabel/CMakeLists.txt
index 5b9c208727..4ccbbc899d 100644
--- a/tests/backend/TextLabel/CMakeLists.txt
+++ b/tests/backend/TextLabel/CMakeLists.txt
@@ -3,7 +3,7 @@ option(ENABLE_TEST_BACKEND_TEXTLABEL "Enable Textlabel Tests" ON)
 if(ENABLE_TEST_BACKEND_TEXTLABEL)
     add_executable (TextLabelTest TextLabelTest.cpp)
 
-    target_link_libraries(TextLabelTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(TextLabelTest labplotbackendlib labplotlib labplottest)
 
     add_test(NAME TextLabelTest COMMAND TextLabelTest)
 endif()
diff --git a/tests/backend/Worksheet/CMakeLists.txt b/tests/backend/Worksheet/CMakeLists.txt
index 05d50c3862..a8e8200e9c 100644
--- a/tests/backend/Worksheet/CMakeLists.txt
+++ b/tests/backend/Worksheet/CMakeLists.txt
@@ -3,13 +3,13 @@ option(ENABLE_TEST_BACKEND_WORKSHEET "Enable Worksheet Tests" ON)
 if(ENABLE_TEST_BACKEND_WORKSHEET)
     add_executable (WorksheetElementTest WorksheetElementTest.cpp)
 
-    target_link_libraries(WorksheetElementTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(WorksheetElementTest labplotbackendlib labplotlib labplottest)
 
     add_test(NAME WorksheetElementTest COMMAND WorksheetElementTest)
 
     add_executable (WorksheetTest WorksheetTest.cpp)
 
-    target_link_libraries(WorksheetTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(WorksheetTest labplotbackendlib labplotlib labplottest)
 
     add_test(NAME WorksheetTest COMMAND WorksheetTest)
 endif()
diff --git a/tests/backend/XYCurve/CMakeLists.txt b/tests/backend/XYCurve/CMakeLists.txt
index 2a8f295a87..f774e0c02f 100644
--- a/tests/backend/XYCurve/CMakeLists.txt
+++ b/tests/backend/XYCurve/CMakeLists.txt
@@ -3,7 +3,7 @@ option(ENABLE_TEST_BACKEND_XYCURVE "Enable XYCurve Tests" ON)
 if(ENABLE_TEST_BACKEND_XYCURVE)
     add_executable (XYCurveTest XYCurveTest.cpp)
 
-    target_link_libraries(XYCurveTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(XYCurveTest labplotbackendlib labplotlib labplottest)
 
     add_test(NAME XYCurveTest COMMAND XYCurveTest)
 endif()
@@ -13,7 +13,7 @@ option(ENABLE_TEST_BACKEND_XYEQUATIONCURVE2 "Enable XYFunctionCurve Tests" ON)
 if(ENABLE_TEST_BACKEND_XYEQUATIONCURVE2)
     add_executable (XYFunctionCurveTest XYFunctionCurveTest.cpp)
 
-    target_link_libraries(XYFunctionCurveTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(XYFunctionCurveTest labplotbackendlib labplotlib labplottest)
 
     add_test(NAME XYFunctionCurveTest COMMAND XYFunctionCurveTest)
 endif()
diff --git a/tests/backend/core/CMakeLists.txt b/tests/backend/core/CMakeLists.txt
index 31a061e441..f9aa4e84b0 100644
--- a/tests/backend/core/CMakeLists.txt
+++ b/tests/backend/core/CMakeLists.txt
@@ -3,7 +3,7 @@ option(ENABLE_TEST_BACKEND_CORE "Enable Core Tests" ON)
 if(ENABLE_TEST_BACKEND_CORE)
     add_executable (AbstractAspectTest AbstractAspectTest.cpp)
 
-    target_link_libraries(AbstractAspectTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(AbstractAspectTest labplotbackendlib labplotlib labplottest)
 
     add_test(NAME AbstractAspectTest COMMAND AbstractAspectTest)
 endif()
diff --git a/tests/backend/gsl/CMakeLists.txt b/tests/backend/gsl/CMakeLists.txt
index 0b8d3778aa..1e723e6999 100644
--- a/tests/backend/gsl/CMakeLists.txt
+++ b/tests/backend/gsl/CMakeLists.txt
@@ -4,13 +4,13 @@ if(ENABLE_TEST_BACKEND_GSL)
     # Currently no test is implemented so disable it for now and keep it
     #add_executable(GSLTest GSLTest.cpp)
 
-    #target_link_libraries(GSLTest labplot2lib labplot2test)
+    #target_link_libraries(GSLTest labplotlib labplottest)
 
     #add_test(NAME GSLTest COMMAND GSLTest)
 
     add_executable(ExpressionParserTest ExpressionParserTest.cpp)
 
-    target_link_libraries(ExpressionParserTest labplot2test labplot2backendlib)
+    target_link_libraries(ExpressionParserTest labplottest labplotbackendlib)
 
     add_test(NAME ExpressionParserTest COMMAND ExpressionParserTest)
 endif()
diff --git a/tests/cartesianplot/CMakeLists.txt b/tests/cartesianplot/CMakeLists.txt
index 089976ad33..5dc62b15f5 100644
--- a/tests/cartesianplot/CMakeLists.txt
+++ b/tests/cartesianplot/CMakeLists.txt
@@ -2,7 +2,7 @@ option(ENABLE_TEST_CARTESIANPLOT "Enable CartesianPlot Tests" ON)
 
 if(ENABLE_TEST_CARTESIANPLOT)
     add_executable (CartesianPlotTest CartesianPlotTest.cpp)
-    target_link_libraries(CartesianPlotTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(CartesianPlotTest labplotbackendlib labplotlib labplottest)
     add_test(NAME CartesianPlotTest COMMAND CartesianPlotTest)
 
     add_subdirectory(plots)
diff --git a/tests/cartesianplot/plots/statisticalplots/CMakeLists.txt b/tests/cartesianplot/plots/statisticalplots/CMakeLists.txt
index 907b5a1cd4..6ae2c4a638 100644
--- a/tests/cartesianplot/plots/statisticalplots/CMakeLists.txt
+++ b/tests/cartesianplot/plots/statisticalplots/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(StatisticalPlotsTest StatisticalPlotsTest.cpp)
 
-target_link_libraries(StatisticalPlotsTest labplot2backendlib labplot2lib labplot2test)
+target_link_libraries(StatisticalPlotsTest labplotbackendlib labplotlib labplottest)
 
 add_test(NAME StatisticalPlotsTest COMMAND StatisticalPlotsTest)
diff --git a/tests/commonfrontend/widgets/CMakeLists.txt b/tests/commonfrontend/widgets/CMakeLists.txt
index 327ebb188f..e4e66b501a 100644
--- a/tests/commonfrontend/widgets/CMakeLists.txt
+++ b/tests/commonfrontend/widgets/CMakeLists.txt
@@ -1,6 +1,6 @@
 add_executable(SpinBoxTest SpinBoxTest.cpp)
 
-target_link_libraries(SpinBoxTest labplot2backendlib labplot2lib labplot2test)
+target_link_libraries(SpinBoxTest labplotbackendlib labplotlib labplottest)
 
 add_test(NAME SpinBoxTest COMMAND SpinBoxTest)
 
diff --git a/tests/commonfrontend/widgets/SpinBoxTest.h b/tests/commonfrontend/widgets/SpinBoxTest.h
index 2a4aa800e4..5cae450004 100644
--- a/tests/commonfrontend/widgets/SpinBoxTest.h
+++ b/tests/commonfrontend/widgets/SpinBoxTest.h
@@ -18,7 +18,7 @@ class SpinBoxTest : public CommonTest {
 
 private Q_SLOTS:
 	void initTestCase() {
-		KLocalizedString::setApplicationDomain("labplot2");
+		KLocalizedString::setApplicationDomain("labplot");
 		QLocale::setDefault(QLocale(QLocale::Language::English));
 	}
 
diff --git a/tests/import_export/ASCII/CMakeLists.txt b/tests/import_export/ASCII/CMakeLists.txt
index f4e7be6be4..c0120acfb4 100644
--- a/tests/import_export/ASCII/CMakeLists.txt
+++ b/tests/import_export/ASCII/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(AsciiFilterTest AsciiFilterTest.cpp)
 
-target_link_libraries(AsciiFilterTest labplot2metatest)
+target_link_libraries(AsciiFilterTest labplotmetatest)
 
 add_test(NAME AsciiFilterTest COMMAND AsciiFilterTest)
diff --git a/tests/import_export/Binary/CMakeLists.txt b/tests/import_export/Binary/CMakeLists.txt
index efed9874ac..7161a541b5 100644
--- a/tests/import_export/Binary/CMakeLists.txt
+++ b/tests/import_export/Binary/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(BinaryFilterTest BinaryFilterTest.cpp)
 
-target_link_libraries(BinaryFilterTest labplot2metatest)
+target_link_libraries(BinaryFilterTest labplotmetatest)
 
 add_test(NAME BinaryFilterTest COMMAND BinaryFilterTest)
diff --git a/tests/import_export/CAN/CMakeLists.txt b/tests/import_export/CAN/CMakeLists.txt
index 127ff548a4..7e0f4f5be8 100644
--- a/tests/import_export/CAN/CMakeLists.txt
+++ b/tests/import_export/CAN/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(BLFFilterTest BLFFilterTest.cpp)
 
-target_link_libraries(BLFFilterTest labplot2metatest)
+target_link_libraries(BLFFilterTest labplotmetatest)
 
 add_test(NAME BLFFilterTest COMMAND BLFFilterTest)
diff --git a/tests/import_export/Datasets/CMakeLists.txt b/tests/import_export/Datasets/CMakeLists.txt
index 564bd36560..3aa2178c9f 100644
--- a/tests/import_export/Datasets/CMakeLists.txt
+++ b/tests/import_export/Datasets/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(DatasetsTest DatasetsTest.cpp)
 
-target_link_libraries(DatasetsTest labplot2backendlib labplot2lib labplot2test)
+target_link_libraries(DatasetsTest labplotbackendlib labplotlib labplottest)
 
 add_test(NAME DatasetsTest COMMAND DatasetsTest)
diff --git a/tests/import_export/FITS/CMakeLists.txt b/tests/import_export/FITS/CMakeLists.txt
index a5c46750d3..5649d5ec8b 100644
--- a/tests/import_export/FITS/CMakeLists.txt
+++ b/tests/import_export/FITS/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(FITSFilterTest FITSFilterTest.cpp)
 
-target_link_libraries(FITSFilterTest labplot2metatest)
+target_link_libraries(FITSFilterTest labplotmetatest)
 
 add_test(NAME FITSFilterTest COMMAND FITSFilterTest)
diff --git a/tests/import_export/HDF5/CMakeLists.txt b/tests/import_export/HDF5/CMakeLists.txt
index 892b48bff4..5892d74795 100644
--- a/tests/import_export/HDF5/CMakeLists.txt
+++ b/tests/import_export/HDF5/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(HDF5FilterTest HDF5FilterTest.cpp)
 
-target_link_libraries(HDF5FilterTest labplot2metatest)
+target_link_libraries(HDF5FilterTest labplotmetatest)
 
 add_test(NAME HDF5FilterTest COMMAND HDF5FilterTest)
diff --git a/tests/import_export/JSON/CMakeLists.txt b/tests/import_export/JSON/CMakeLists.txt
index 64750360fe..23a76f3741 100644
--- a/tests/import_export/JSON/CMakeLists.txt
+++ b/tests/import_export/JSON/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(JSONFilterTest JSONFilterTest.cpp)
 
-target_link_libraries(JSONFilterTest labplot2metatest)
+target_link_libraries(JSONFilterTest labplotmetatest)
 
 add_test(NAME JSONFilterTest COMMAND JSONFilterTest)
diff --git a/tests/import_export/MCAP/CMakeLists.txt b/tests/import_export/MCAP/CMakeLists.txt
index c8e09b6133..80b41e19d8 100644
--- a/tests/import_export/MCAP/CMakeLists.txt
+++ b/tests/import_export/MCAP/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(MCAPFilterTest MCAPFilterTest.cpp)
 
-target_link_libraries(MCAPFilterTest labplot2metatest)
+target_link_libraries(MCAPFilterTest labplotmetatest)
 
 add_test(NAME MCAPFilterTest COMMAND MCAPFilterTest)
diff --git a/tests/import_export/MQTT/CMakeLists.txt b/tests/import_export/MQTT/CMakeLists.txt
index 7ab90544c9..dab2472f4b 100644
--- a/tests/import_export/MQTT/CMakeLists.txt
+++ b/tests/import_export/MQTT/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(MQTTTest MQTTTest.cpp)
 
-target_link_libraries(MQTTTest Qt${QT_VERSION_MAJOR}::Mqtt labplot2backendlib labplot2lib labplot2test)
+target_link_libraries(MQTTTest Qt${QT_VERSION_MAJOR}::Mqtt labplotbackendlib labplotlib labplottest)
 
 add_test(NAME MQTTTest COMMAND MQTTTest)
diff --git a/tests/import_export/Matio/CMakeLists.txt b/tests/import_export/Matio/CMakeLists.txt
index a38f9629e5..5a17484bde 100644
--- a/tests/import_export/Matio/CMakeLists.txt
+++ b/tests/import_export/Matio/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(MatioFilterTest MatioFilterTest.cpp)
 
-target_link_libraries(MatioFilterTest labplot2metatest)
+target_link_libraries(MatioFilterTest labplotmetatest)
 
 add_test(NAME MatioFilterTest COMMAND MatioFilterTest)
diff --git a/tests/import_export/NetCDF/CMakeLists.txt b/tests/import_export/NetCDF/CMakeLists.txt
index d2b943a800..8319f35e9f 100644
--- a/tests/import_export/NetCDF/CMakeLists.txt
+++ b/tests/import_export/NetCDF/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(NetCDFFilterTest NetCDFFilterTest.cpp)
 
-target_link_libraries(NetCDFFilterTest labplot2metatest)
+target_link_libraries(NetCDFFilterTest labplotmetatest)
 
 add_test(NAME NetCDFFilterTest COMMAND NetCDFFilterTest)
diff --git a/tests/import_export/Ods/CMakeLists.txt b/tests/import_export/Ods/CMakeLists.txt
index 7487fcfabf..4730942eba 100644
--- a/tests/import_export/Ods/CMakeLists.txt
+++ b/tests/import_export/Ods/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(OdsFilterTest OdsFilterTest.cpp)
 
-target_link_libraries(OdsFilterTest labplot2metatest)
+target_link_libraries(OdsFilterTest labplotmetatest)
 
 add_test(NAME OdsFilterTest COMMAND OdsFilterTest)
diff --git a/tests/import_export/Project/CMakeLists.txt b/tests/import_export/Project/CMakeLists.txt
index 467f0c8b60..5138e6b3f7 100644
--- a/tests/import_export/Project/CMakeLists.txt
+++ b/tests/import_export/Project/CMakeLists.txt
@@ -9,6 +9,6 @@ if(ENABLE_LIBORIGIN)
     endif()
 endif()
 
-target_link_libraries(ProjectImportTest labplot2metatest)
+target_link_libraries(ProjectImportTest labplotmetatest)
 
 add_test(NAME ProjectImportTest COMMAND ProjectImportTest)
diff --git a/tests/import_export/ROOT/CMakeLists.txt b/tests/import_export/ROOT/CMakeLists.txt
index abf3dc572a..6345d2ce46 100644
--- a/tests/import_export/ROOT/CMakeLists.txt
+++ b/tests/import_export/ROOT/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(ROOTFilterTest ROOTFilterTest.cpp)
 
-target_link_libraries(ROOTFilterTest labplot2metatest)
+target_link_libraries(ROOTFilterTest labplotmetatest)
 
 add_test(NAME ROOTFilterTest COMMAND ROOTFilterTest)
diff --git a/tests/import_export/ReadStat/CMakeLists.txt b/tests/import_export/ReadStat/CMakeLists.txt
index 3cbe0e49c0..9ff69d87cc 100644
--- a/tests/import_export/ReadStat/CMakeLists.txt
+++ b/tests/import_export/ReadStat/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(ReadStatFilterTest ReadStatFilterTest.cpp)
 
-target_link_libraries(ReadStatFilterTest labplot2metatest)
+target_link_libraries(ReadStatFilterTest labplotmetatest)
 
 add_test(NAME ReadStatFilterTest COMMAND ReadStatFilterTest)
diff --git a/tests/import_export/SQL/CMakeLists.txt b/tests/import_export/SQL/CMakeLists.txt
index 9597a73c6e..2e95026f5f 100644
--- a/tests/import_export/SQL/CMakeLists.txt
+++ b/tests/import_export/SQL/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(ImportSqlDatabaseTest ImportSqlDatabaseTest.cpp)
 
-target_link_libraries(ImportSqlDatabaseTest labplot2metatest)
+target_link_libraries(ImportSqlDatabaseTest labplotmetatest)
 
 add_test(NAME ImportSqlDatabaseTest COMMAND ImportSqlDatabaseTest)
diff --git a/tests/import_export/Spice/CMakeLists.txt b/tests/import_export/Spice/CMakeLists.txt
index fa62082f3b..7ff02bb284 100644
--- a/tests/import_export/Spice/CMakeLists.txt
+++ b/tests/import_export/Spice/CMakeLists.txt
@@ -1,7 +1,7 @@
 add_executable(SpiceFilterTest SpiceFilterTest.cpp)
 target_compile_definitions(SpiceFilterTest PRIVATE SPICEFILTERTEST_EN)
 
-target_link_libraries(SpiceFilterTest labplot2metatest)
-target_compile_definitions(labplot2backendlib PRIVATE SPICEFILTERTEST_EN)
+target_link_libraries(SpiceFilterTest labplotmetatest)
+target_compile_definitions(labplotbackendlib PRIVATE SPICEFILTERTEST_EN)
 
 add_test(NAME SpiceFilterTest COMMAND SpiceFilterTest)
diff --git a/tests/import_export/XLSX/CMakeLists.txt b/tests/import_export/XLSX/CMakeLists.txt
index 5b6b0b02f4..34c20b58a8 100644
--- a/tests/import_export/XLSX/CMakeLists.txt
+++ b/tests/import_export/XLSX/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(XLSXFilterTest XLSXFilterTest.cpp)
 
-target_link_libraries(XLSXFilterTest labplot2metatest)
+target_link_libraries(XLSXFilterTest labplotmetatest)
 
 add_test(NAME XLSXFilterTest COMMAND XLSXFilterTest)
diff --git a/tests/livedata/CMakeLists.txt b/tests/livedata/CMakeLists.txt
index 2f6d93baf2..a095c1d4c0 100644
--- a/tests/livedata/CMakeLists.txt
+++ b/tests/livedata/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(LiveDataTest LiveDataTest.cpp)
 
-target_link_libraries(LiveDataTest labplot2backendlib labplot2lib labplot2test)
+target_link_libraries(LiveDataTest labplotbackendlib labplotlib labplottest)
 
 add_test(NAME LiveDataTest COMMAND LiveDataTest)
diff --git a/tests/matrix/CMakeLists.txt b/tests/matrix/CMakeLists.txt
index 9d9bd22975..1cb36d770e 100644
--- a/tests/matrix/CMakeLists.txt
+++ b/tests/matrix/CMakeLists.txt
@@ -3,13 +3,13 @@ option(ENABLE_TEST_MATRIX "Enable Matrix Tests" ON)
 if(ENABLE_TEST_MATRIX)
     add_executable (MatrixTest MatrixTest.cpp)
 
-    target_link_libraries(MatrixTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(MatrixTest labplotbackendlib labplotlib labplottest)
 
     add_test(NAME MatrixTest COMMAND MatrixTest)
 
     add_executable (MatrixFormulaTest MatrixFormulaTest.cpp)
 
-    target_link_libraries(MatrixFormulaTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(MatrixFormulaTest labplotbackendlib labplotlib labplottest)
 
     add_test(NAME MatrixFormulaTest COMMAND MatrixFormulaTest)
 endif()
diff --git a/tests/multirange/CMakeLists.txt b/tests/multirange/CMakeLists.txt
index 9b338a0313..9620280524 100644
--- a/tests/multirange/CMakeLists.txt
+++ b/tests/multirange/CMakeLists.txt
@@ -2,14 +2,14 @@ option(ENABLE_TEST_MULTIRANGE "Enable Multirange Tests" ON)
 
 if(ENABLE_TEST_MULTIRANGE)
     add_executable (MultiRangeTest MultiRangeTest.cpp)
-    target_link_libraries(MultiRangeTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(MultiRangeTest labplotbackendlib labplotlib labplottest)
     add_test(NAME MultiRangeTest COMMAND MultiRangeTest)
 
     add_executable (MultiRangeTest2 MultiRangeTest2.cpp)
-    target_link_libraries(MultiRangeTest2 labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(MultiRangeTest2 labplotbackendlib labplotlib labplottest)
     add_test(NAME MultiRangeTest2 COMMAND MultiRangeTest2)
 
     add_executable (MultiRangeTest3 MultiRangeTest3.cpp)
-    target_link_libraries(MultiRangeTest3 labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(MultiRangeTest3 labplotbackendlib labplotlib labplottest)
     add_test(NAME MultiRangeTest3 COMMAND MultiRangeTest3)
 endif()
diff --git a/tests/notebook/CMakeLists.txt b/tests/notebook/CMakeLists.txt
index 3c063d6f96..e40abcc623 100644
--- a/tests/notebook/CMakeLists.txt
+++ b/tests/notebook/CMakeLists.txt
@@ -3,7 +3,7 @@ option(ENABLE_TEST_NOTEBOOK "Enable Notebook Tests" ON)
 if(ENABLE_TEST_NOTEBOOK)
     add_executable (NotebookTest NotebookTest.cpp)
 
-    target_link_libraries(NotebookTest labplot2lib labplot2backendlib labplot2test)
+    target_link_libraries(NotebookTest labplotlib labplotbackendlib labplottest)
 
     add_test(NAME NotebookTest COMMAND NotebookTest)
 endif()
diff --git a/tests/nsl/baseline/CMakeLists.txt b/tests/nsl/baseline/CMakeLists.txt
index dacb6cc83b..fe346bed48 100644
--- a/tests/nsl/baseline/CMakeLists.txt
+++ b/tests/nsl/baseline/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(NSLBaselineTest NSLBaselineTest.cpp)
 
-target_link_libraries(NSLBaselineTest labplot2test ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES})
+target_link_libraries(NSLBaselineTest labplottest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES})
 
 add_test(NAME NSLBaselineTest COMMAND NSLBaselineTest)
diff --git a/tests/nsl/dft/CMakeLists.txt b/tests/nsl/dft/CMakeLists.txt
index fcfa0b768c..c0eb68f43f 100644
--- a/tests/nsl/dft/CMakeLists.txt
+++ b/tests/nsl/dft/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(NSLDFTTest NSLDFTTest.cpp)
 
-target_link_libraries(NSLDFTTest labplot2test ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} ${FFTW3_LIBRARIES})
+target_link_libraries(NSLDFTTest labplottest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} ${FFTW3_LIBRARIES})
 
 add_test(NAME NSLDFTTest COMMAND NSLDFTTest)
diff --git a/tests/nsl/diff/CMakeLists.txt b/tests/nsl/diff/CMakeLists.txt
index 23279dcf63..4d1268f46f 100644
--- a/tests/nsl/diff/CMakeLists.txt
+++ b/tests/nsl/diff/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(NSLDiffTest NSLDiffTest.cpp)
 
-target_link_libraries(NSLDiffTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} labplot2test)
+target_link_libraries(NSLDiffTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} labplottest)
 
 add_test(NAME NSLDiffTest COMMAND NSLDiffTest)
diff --git a/tests/nsl/filter/CMakeLists.txt b/tests/nsl/filter/CMakeLists.txt
index 4bd4a4e69d..501f8e7197 100644
--- a/tests/nsl/filter/CMakeLists.txt
+++ b/tests/nsl/filter/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(NSLFilterTest NSLFilterTest.cpp)
 
-target_link_libraries(NSLFilterTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} ${FFTW3_LIBRARIES} labplot2test)
+target_link_libraries(NSLFilterTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} ${FFTW3_LIBRARIES} labplottest)
 
 add_test(NAME NSLFilterTest COMMAND NSLFilterTest)
diff --git a/tests/nsl/fit/CMakeLists.txt b/tests/nsl/fit/CMakeLists.txt
index 3b7e4e4f17..549a941825 100644
--- a/tests/nsl/fit/CMakeLists.txt
+++ b/tests/nsl/fit/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(NSLFitTest NSLFitTest.cpp)
 
-target_link_libraries(NSLFitTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} ${LIBCERF_LIBRARIES} labplot2test)
+target_link_libraries(NSLFitTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} ${LIBCERF_LIBRARIES} labplottest)
 
 add_test(NAME NSLFitTest COMMAND NSLFitTest)
diff --git a/tests/nsl/geom/CMakeLists.txt b/tests/nsl/geom/CMakeLists.txt
index de1c42f05f..8f2fcf1161 100644
--- a/tests/nsl/geom/CMakeLists.txt
+++ b/tests/nsl/geom/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(NSLGeomTest NSLGeomTest.cpp)
 
-target_link_libraries(NSLGeomTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} labplot2test)
+target_link_libraries(NSLGeomTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} labplottest)
 
 add_test(NAME NSLGeomTest COMMAND NSLGeomTest)
diff --git a/tests/nsl/int/CMakeLists.txt b/tests/nsl/int/CMakeLists.txt
index 5b678b96c1..93ef29c2a6 100644
--- a/tests/nsl/int/CMakeLists.txt
+++ b/tests/nsl/int/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(NSLIntTest NSLIntTest.cpp)
 
-target_link_libraries(NSLIntTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} labplot2test)
+target_link_libraries(NSLIntTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} labplottest)
 
 add_test(NAME NSLIntTest COMMAND NSLIntTest)
diff --git a/tests/nsl/math/CMakeLists.txt b/tests/nsl/math/CMakeLists.txt
index 42637242e6..b7ba30a6dc 100644
--- a/tests/nsl/math/CMakeLists.txt
+++ b/tests/nsl/math/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(NSLMathTest NSLMathTest.cpp)
 
-target_link_libraries(NSLMathTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} labplot2test)
+target_link_libraries(NSLMathTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} labplottest)
 
 add_test(NAME NSLMathTest COMMAND NSLMathTest)
diff --git a/tests/nsl/peak/CMakeLists.txt b/tests/nsl/peak/CMakeLists.txt
index 9c7b286d36..58233e80f0 100644
--- a/tests/nsl/peak/CMakeLists.txt
+++ b/tests/nsl/peak/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(NSLPeakTest NSLPeakTest.cpp)
 
-target_link_libraries(NSLPeakTest labplot2test)
+target_link_libraries(NSLPeakTest labplottest)
 
 add_test(NAME NSLPeakTest COMMAND NSLPeakTest)
diff --git a/tests/nsl/sf/CMakeLists.txt b/tests/nsl/sf/CMakeLists.txt
index e89ddc3b93..2a01e5ceed 100644
--- a/tests/nsl/sf/CMakeLists.txt
+++ b/tests/nsl/sf/CMakeLists.txt
@@ -1,13 +1,13 @@
 # basic functions
 add_executable(NSLSFBasicTest NSLSFBasicTest.cpp)
 
-target_link_libraries(NSLSFBasicTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} ${LIBCERF_LIBRARIES} labplot2test)
+target_link_libraries(NSLSFBasicTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} ${LIBCERF_LIBRARIES} labplottest)
 
 add_test(NAME NSLSFBasicTest COMMAND NSLSFBasicTest)
 
 # window functions
 add_executable(NSLSFWindowTest NSLSFWindowTest.cpp)
 
-target_link_libraries(NSLSFWindowTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} labplot2test)
+target_link_libraries(NSLSFWindowTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} labplottest)
 
 add_test(NAME NSLSFWindowTest COMMAND NSLSFWindowTest)
diff --git a/tests/nsl/smooth/CMakeLists.txt b/tests/nsl/smooth/CMakeLists.txt
index 7551ac3b71..c51ec757d3 100644
--- a/tests/nsl/smooth/CMakeLists.txt
+++ b/tests/nsl/smooth/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(NSLSmoothTest NSLSmoothTest.cpp)
 
-target_link_libraries(NSLSmoothTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} labplot2test)
+target_link_libraries(NSLSmoothTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} labplottest)
 
 add_test(NAME NSLSmoothTest COMMAND NSLSmoothTest)
diff --git a/tests/nsl/stats/CMakeLists.txt b/tests/nsl/stats/CMakeLists.txt
index e9c5d91c8b..00e187cdce 100644
--- a/tests/nsl/stats/CMakeLists.txt
+++ b/tests/nsl/stats/CMakeLists.txt
@@ -1,5 +1,5 @@
 add_executable(NSLStatsTest NSLStatsTest.cpp)
 
-target_link_libraries(NSLStatsTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} labplot2test)
+target_link_libraries(NSLStatsTest ${GSL_LIBRARIES} ${GSL_CBLAS_LIBRARIES} labplottest)
 
 add_test(NAME NSLStatsTest COMMAND NSLStatsTest)
diff --git a/tests/spreadsheet/CMakeLists.txt b/tests/spreadsheet/CMakeLists.txt
index ab85772537..82a0381130 100644
--- a/tests/spreadsheet/CMakeLists.txt
+++ b/tests/spreadsheet/CMakeLists.txt
@@ -2,14 +2,14 @@ option(ENABLE_TEST_SPREADSHEET "Enable Spreadsheet Tests" ON)
 
 if(ENABLE_TEST_SPREADSHEET)
     add_executable (SpreadsheetTest SpreadsheetTest.cpp)
-    target_link_libraries(SpreadsheetTest labplot2metatest)
+    target_link_libraries(SpreadsheetTest labplotmetatest)
     add_test(NAME SpreadsheetTest COMMAND SpreadsheetTest)
 
     add_executable (SpreadsheetFormulaTest SpreadsheetFormulaTest.cpp)
-    target_link_libraries(SpreadsheetFormulaTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(SpreadsheetFormulaTest labplotbackendlib labplotlib labplottest)
     add_test(NAME SpreadsheetFormulaTest COMMAND SpreadsheetFormulaTest)
 
     add_executable (SpreadsheetGenerateDataTest SpreadsheetGenerateDataTest.cpp)
-    target_link_libraries(SpreadsheetGenerateDataTest labplot2backendlib labplot2lib labplot2test)
+    target_link_libraries(SpreadsheetGenerateDataTest labplotbackendlib labplotlib labplottest)
     add_test(NAME SpreadsheetGenerateDataTest COMMAND SpreadsheetGenerateDataTest)
 endif()
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.
diff --git a/src/tools/TeXRenderer.cpp b/src/tools/TeXRenderer.cpp
index a1b88f7651..f889a95f95 100644
--- a/src/tools/TeXRenderer.cpp
+++ b/src/tools/TeXRenderer.cpp
@@ -275,9 +275,9 @@ QByteArray TeXRenderer::imageFromDVI(const QTemporaryFile& file, const int dpi,
 	// convert: PS -> PNG
 	QProcess convertProcess;
 #if defined(HAVE_WINDOWS)
 	// need to set path to magick coder modules (which are in the labplot2 directory)
 	QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
-	env.insert(QStringLiteral("MAGICK_CODER_MODULE_PATH"), QString::fromLocal8Bit(qgetenv("PROGRAMFILES")) + QStringLiteral("\\labplot2"));
+	env.insert(QStringLiteral("MAGICK_CODER_MODULE_PATH"), QString::fromLocal8Bit(qgetenv("PROGRAMFILES")) + QStringLiteral("\\labplot"));
 	convertProcess.setProcessEnvironment(env);
 #endif
 	const QString convertFullPath = safeExecutableName(QStringLiteral("convert"));
@@ -275,9 +275,9 @@ QByteArray TeXRenderer::imageFromDVI(const QTemporaryFile& file, const int dpi,
 	QProcess convertProcess;
 #if defined(HAVE_WINDOWS)
-	// need to set path to magick coder modules (which are in the labplot2 directory)
+	// need to set path to magick coder modules (which are in the labplot directory)
 	QProcessEnvironment env = QProcessEnvironment::systemEnvironment();